aah
abacinate
abandon
abase
abash
abate
abbreviate
abdicate
abduce
abduct
aberrate
abet
abhor
abide
abide_by
abjure
ablactate
ablate
abnegate
abolish
abominate
abort
abound
abound_in
about-face
abrade
abrase
abreact
abridge
abrogate
abscise
abscond
abseil
absent
absolve
absorb
absquatulate
abstain
abstract
abuse
abut
aby
abye
accede
accelerate
accent
accentuate
accept
access
accession
acclaim
acclimate
acclimatise
acclimatize
accommodate
accompany
accomplish
accord
accost
account
account_for
accouter
accoutre
accredit
accrete
accrue
acculturate
accumulate
accurse
accuse
accustom
ace
acerbate
acetify
acetylate
acetylise
acetylize
ache
achieve
achromatise
achromatize
acid-wash
acidify
acidulate
acknowledge
acquaint
acquiesce
acquire
acquit
act
action
activate
actualise
actualize
actuate
act_as
act_involuntarily
act_on
act_out
act_reflexively
act_superior
act_up
act_upon
acuminate
ad-lib
adapt
add
addict
addle
address
adduce
adduct
add_on
add_to
add_together
add_up
adhere
adjoin
adjourn
adjudge
adjudicate
adjure
adjust
admeasure
administer
administrate
admire
admit
admix
admonish
adolesce
adopt
adore
adorn
adsorb
adulate
adulterate
adumbrate
advance
advantage
advect
adventure
advert
advertise
advertize
advise
advocate
aerate
aerify
aerosolise
aerosolize
aestivate
affect
affiance
affiliate
affirm
affix
afflict
afford
afforest
affranchise
affright
affront
age
agenise
agenize
agglomerate
agglutinate
aggrade
aggrandise
aggrandize
aggravate
aggregate
aggress
aggrieve
aggroup
agitate
agnise
agnize
agonise
agonize
agree
aid
ail
aim
air
air-condition
air-cool
air-drop
air-freight
air-ship
air-slake
airbrush
airfreight
airlift
airmail
airt
air_out
alarm
alchemise
alchemize
alcoholise
alcoholize
alert
alibi
alien
alienate
alight
align
aliment
aline
alkalify
alkalinise
alkalinize
alkalise
alkalize
allay
allege
allegorise
allegorize
alleviate
alligator
alliterate
allocate
allot
allow
allowance
allow_for
allow_in
alloy
allude
allure
ally
ally_with
alphabetise
alphabetize
alter
altercate
alternate
aluminise
aluminize
amalgamate
amass
amaze
ambition
amble
ambulate
ambuscade
ambush
ameliorate
amend
amerce
americanise
americanize
ammoniate
ammonify
amnesty
amortise
amortize
amount
amplify
amputate
amuse
anaesthetise
anaesthetize
anagram
anagrammatise
anagrammatize
analogise
analogize
analyse
analyze
anastomose
anathematise
anathematize
anathemise
anathemize
anatomise
anatomize
anchor
ancylose
anele
anesthetise
anesthetize
anger
angle
angle-park
anglicise
anglicize
anguish
angulate
animadvert
animalise
animalize
animate
animise
animize
ankylose
anneal
annex
annihilate
annotate
announce
annoy
annul
annunciate
anodise
anodize
anoint
answer
answer_for
antagonise
antagonize
ante
antecede
antedate
ante_up
anthologise
anthologize
anthropomorphise
anthropomorphize
antic
anticipate
antiquate
antique
antisepticize
ape
aphorise
aphorize
apologise
apologize
apostatise
apostatize
apostrophise
apostrophize
apotheose
apotheosise
apotheosize
appal
appall
apparel
appeal
appear
appease
append
apperceive
appertain
applaud
applique
apply
appoint
apportion
appose
appraise
appreciate
apprehend
apprentice
apprise
apprize
approach
approbate
appropriate
approve
approximate
aquaplane
aquatint
arbitrage
arbitrate
arborise
arborize
arc
arch
archaise
archaize
archive
arch_over
argue
argufy
arise
arm
armor
armour
aromatise
aromatize
arouse
arraign
arrange
array
arrest
arrive
arrive_at
arrogate
arse_about
arse_around
arterialise
arterialize
article
articulate
ascend
ascertain
ascribe
ash
ask
ask_for
ask_for_it
ask_for_trouble
ask_in
ask_out
ask_over
ask_round
asperse
asphalt
asphyxiate
aspirate
aspire
assail
assassinate
assault
assay
assemble
assent
assert
assert_oneself
assess
asseverate
assibilate
assign
assimilate
assist
associate
assoil
assonate
assort
assuage
assume
assure
asterisk
astonish
astound
astringe
astrogate
atom-bomb
atomise
atomize
atone
atrophy
attach
attach_to
attack
attain
attaint
attemper
attempt
attend
attend_to
attenuate
attest
attire
attitudinise
attitudinize
attorn
attract
attribute
attune
auction
auctioneer
auction_off
audit
audition
augment
augur
aurify
auscultate
auspicate
authenticate
author
authorise
authorize
autoclave
autograph
automate
automatise
automatize
automobile
autopsy
autotomise
autotomize
avail
avalanche
avenge
aver
average
average_out
avert
avianise
avianize
aviate
avoid
avouch
avow
avulse
await
awake
awaken
award
awe
ax
axe
azure
baa
babbitt
babble
babble_out
baby
baby-sit
bach
bachelor
back
backbite
backcross
backdate
backfire
background
backhand
backlash
backlog
backpack
backpedal
backscatter
backslap
backslide
backspace
backstitch
backstop
backstroke
backtrack
back_away
back_down
back_off
back_out
back_up
bacterise
bacterize
badge
badger
badmouth
baffle
bag
bail
bail_out
bait
bake
balance
bald
bale
bale_out
balk
balkanise
balkanize
ball
ballast
balloon
ballot
ballyhoo
ballyrag
ball_over
ball_up
bamboozle
ban
band
bandage
bandy
bandy_about
band_oneself
band_together
bang
bang_out
bang_up
banish
bank
bankroll
bankrupt
banquet
banter
baptise
baptize
bar
barb
barbarise
barbarize
barbecue
barbeque
barber
bard
barde
bare
barf
bargain
bargain_down
barge
barge_in
bark
barnstorm
baronetise
baronetize
barrack
barrage
barrage_jam
barrel
barricade
barricado
barter
barter_away
bar_hop
bar_mitzvah
base
bash
basify
bask
basset
bastardise
bastardize
baste
bastinado
bat
batch
bate
batfowl
bath
bathe
batik
batten
batten_down
batter
battle
bat_mitzvah
baulk
bawl
bawl_out
bay
bayonet
be
beach
beacon
bead
beak
beam
bean
bear
beard
bear_away
bear_down
bear_down_on
bear_down_upon
bear_in_mind
bear_off
bear_on
bear_out
bear_up
bear_upon
bear_witness
beat
beatify
beat_about
beat_around_the_bush
beat_a_retreat
beat_back
beat_down
beat_in
beat_out
beat_up
beautify
beaver
beaver_away
bebop
becalm
bechance
becharm
beckon
becloud
become
become_flat
bed
bed-hop
bedamn
bedaub
bedaze
bedazzle
bedeck
bedevil
bedew
bedhop
bedight
bedim
bedizen
bedraggle
bed_down
beef
beef_up
beep
beeswax
beetle
beetle_off
befall
befit
befog
befool
befoul
befriend
befuddle
beg
beget
beggar
begild
begin
begrime
begrudge
beguile
beg_off
behave
behead
behold
behoove
behove
bejewel
belabor
belabour
belay
belch
beleaguer
belie
believe
believe_in
belittle
bell
bellow
belly
belly-flop
belly-land
bellyache
bellylaugh
belly_dance
belly_out
bell_the_cat
belong
belong_to
belt
belt_along
belt_down
belt_out
belt_up
bemire
bemoan
bemock
bemuse
bench
bend
benday
bend_over_backwards
benefact
benefice
beneficiate
benefit
benficiate
benight
benumb
beplaster
bequeath
berate
bereave
berry
berth
beseech
beseem
beset
beshrew
besiege
besmear
besmirch
besot
bespangle
bespatter
bespeak
bespeckle
bespot
besprinkle
best
bestialise
bestialize
bestir
bestir_oneself
bestow
bestrew
bestride
bet
betake_oneself
bethink
betide
betoken
betray
betroth
better
bet_on
bevel
bewail
beware
bewhisker
bewilder
bewitch
bewray
be_active
be_adrift
be_after
be_amiss
be_at_pains
be_born
be_due
be_full
be_given
be_intimate
be_on
be_on_cloud_nine
be_on_the_ball
be_quiet
be_sick
be_well
be_with_it
bias
bib
bicker
bicycle
bid
bide
biff
bifurcate
bight
bike
bilge
bilk
bill
billet
billow
bin
bind
bind_off
bind_over
binge
bioassay
biodegrade
birch
bird
bird-nest
birdie
birdlime
birdnest
birdwatch
birl
birle
birr
birth
bisect
bitch
bite
bite_off
bite_out
bitt
bitter
bituminise
bituminize
bivouac
blab
blabber
blab_out
black
blackball
blackberry
blacken
blacken_out
blackguard
blackjack
blacklead
blackleg
blacklist
blackmail
blacktop
blackwash
black_market
black_marketeer
black_out
blame
blanch
blandish
blank
blanket
blanket_jam
blank_out
blare
blare_out
blarney
blaspheme
blast
blast_off
blat
blate
blather
blat_out
blaze
blaze_away
blaze_out
blaze_up
blazon
blazon_out
bleach
bleach_out
blear
bleat
bleed
bleep
blemish
blench
blend
blend_in
bless
blether
blight
blind
blindfold
blindside
blink
blinker
blink_away
blister
blither
blitz
blitzkrieg
bloat
blob
block
blockade
block_off
block_out
block_up
blog
blood
bloody
bloom
blossom
blossom_forth
blossom_out
blot
blotch
blot_out
bloviate
blow
blow-dry
blow_a_fuse
blow_off
blow_out
blow_out_of_the_water
blow_over
blow_up
blub
blubber
blubber_out
bludgeon
blue
blue-pencil
blueprint
bluff
bluff_out
blunder
blunder_out
blunt
blur
blurt
blurt_out
blush
bluster
board
board_up
boast
boat
boat-race
bob
bobble
bobsled
bob_about
bob_around
bob_under
bob_up
bode
bodge
body
body-surf
bodypaint
body_forth
body_guard
bog
bogey
boggle
bog_down
boil
boil_down
boil_over
boldface
bollix
bollix_up
bollocks
bollocks_up
bolshevise
bolshevize
bolster
bolster_up
bolt
bolt_down
bolt_out
bomb
bombard
bombilate
bombinate
bombproof
bomb_out
bomb_up
bond
bonderise
bonderize
bone
bone_up
bong
bonk
bonnet
boo
boob
boogie
book
book_up
boom
boomerang
boom_out
boondoggle
boost
boost_up
boot
bootleg
bootlick
bootstrap
boot_out
booze
bop
border
border_on
bore
borrow
bosom
boss
boss_around
botanise
botanize
botch
botch_up
bother
bottle
bottlefeed
bottleneck
bottle_up
bottom
bottom_out
bounce
bounce_back
bounce_out
bound
bound_off
bourgeon
bouse
bow
bowdlerise
bowdlerize
bower
bowl
bowl_over
bowse
bow_down
bow_out
box
box_in
box_up
boycott
brabble
brace
brace_oneself_for
brace_up
brachiate
bracket
bracket_out
brad
brag
braid
brail
braille
brain
brainstorm
brainwash
braise
brake
branch
branch_out
brand
brandish
brandmark
brattice
brattle
brave
brave_out
bravo
brawl
bray
braze
brazen
breach
bread
break
break-dance
breakfast
break_apart
break_away
break_bread
break_camp
break_dance
break_down
break_even
break_in
break_into
break_loose
break_off
break_open
break_out
break_short
break_through
break_up
break_water
break_wind
break_with
bream
breast
breastfeed
breaststroke
breathalyse
breathalyze
breathe
breathe_in
breathe_out
brecciate
breed
breeze
breeze_through
brevet
brew
bribe
brick_in
brick_over
brick_up
bridge
bridge_over
bridle
bridle_at
bridle_up
brief
brigade
brighten
brim
brim_over
brine
bring
bring_about
bring_around
bring_back
bring_down
bring_forth
bring_forward
bring_home
bring_home_the_bacon
bring_in
bring_off
bring_on
bring_oneself
bring_out
bring_outside
bring_round
bring_through
bring_to
bring_together
bring_to_bear
bring_up
brisk
brisken
brisk_up
bristle
bristle_at
bristle_up
broach
broadcast
broaden
broadside
brocade
broider
broil
broker
bromate
brominate
bronze
brooch
brood
brook
broom
browbeat
brown
brown-nose
browse
bruise
bruit
brunch
brush
brush_aside
brush_down
brush_off
brush_on
brush_up
brutalise
brutalize
bubble
bubble_over
bubble_up
buccaneer
buck
bucket
bucket_along
buckle
buckle_down
buckle_under
buckram
buck_up
bud
budge
budget
budget_for
buff
buffalo
buffer
buffet
bug
bugger
bugger_off
bugle
bug_out
build
build_in
build_on
build_up
build_upon
bulge
bulge_out
bulk
bulk_large
bull
bulldog
bulldoze
bulletin
bulletproof
bullet_vote
bullshit
bully
bullyrag
bully_off
bull_through
bulwark
bum
bumble
bump
bump_around
bump_into
bump_off
bump_up
bum_about
bum_around
bunch
bunch_together
bunch_up
bunco
bundle
bundle_off
bundle_up
bung
bungle
bunk
bunker
bunk_down
bunk_off
bunt
buoy
buoy_up
bur
burble
burden
burgeon
burgeon_forth
burglarise
burglarize
burgle
burke
burl
burlesque
burn
burnish
burn_down
burn_off
burn_out
burn_up
burp
burr
burrow
burst
burst_forth
burst_in_on
burst_out
burst_upon
burthen
bury
bus
bush
bushel
bushwhack
bush_out
busk
buss
bust
bustle
bustle_about
bust_up
busy
butcher
butt
butt-weld
butter
butterfly
butter_up
button
buttonhole
button_up
buttress
buttweld
butt_against
butt_in
butt_on
butylate
buy
buy_at
buy_back
buy_food
buy_in
buy_into
buy_it
buy_off
buy_out
buy_the_farm
buy_time
buy_up
buzz
buzz_off
by-bid
bypass
ca-ca
cab
cabal
cabbage
cabin
cable
cache
cachinnate
cackel
cackle
caddie
caddy
cadge
cage
cage_in
cajole
cake
cakewalk
calcify
calcimine
calcine
calculate
calendar
calender
calibrate
caliper
calk
call
calligraph
calliper
callous
callus
call_at
call_attention
call_back
call_down
call_for
call_forth
call_in
call_into_question
call_it_a_day
call_it_quits
call_off
call_on
call_on_the_carpet
call_out
call_the_shots
call_the_tune
call_to_order
call_up
calm
calm_down
calumniate
calve
camber
camouflage
camp
campaign
camphorate
camp_down
camp_out
can
canal
canalise
canalize
cancel
cancel_out
candle
candy
cane
canker
cannibalise
cannibalize
cannon
cannonade
cannonball_along
cannulate
cannulise
cannulize
canoe
canonise
canonize
canoodle
canopy
cant
canter
cantilever
cantillate
canton
cant_over
canulate
canvas
canvass
cap
capacitate
caparison
caper
capitalise
capitalize
capitulate
caponise
caponize
capriole
capsize
capsulate
capsule
capsulise
capsulize
captain
caption
captivate
capture
cap_off
caracole
caramelise
caramelize
caravan
carbonate
carbonise
carbonize
carboxylate
carburet
carburise
carburize
card
care
careen
career
caress
care_a_hang
care_for
caricature
carjack
cark
carmine
carnalise
carnalize
carnify
carol
carom
carouse
carp
carpenter
carpet
carpet_bomb
carry
carry-the_can
carry_away
carry_back
carry_forward
carry_off
carry_on
carry_out
carry_over
carry_through
carry_to_term
carry_weight
cart
cartoon
cartwheel
cart_away
cart_off
carve
carve_out
carve_up
cascade
cascade_down
case
caseate
cash
cashier
cash_in
cash_in_on
cash_out
casket
cast
castigate
castle
castrate
cast_about
cast_anchor
cast_around
cast_aside
cast_away
cast_down
cast_off
cast_on
cast_out
cat
catabolise
catabolize
catalog
catalogue
catalyse
catalyze
catapult
catcall
catch
catch_a_glimpse
catch_a_wink
catch_cold
catch_fire
catch_it
catch_on
catch_out
catch_sight
catch_up
catch_up_with
catechise
catechize
categorise
categorize
catenate
catenulate
cater
caterwaul
cathect
catheterise
catheterize
catholicise
catholicize
catnap
caucus
caulk
cause
causeway
cause_to_be_perceived
cause_to_sleep
cauterise
cauterize
caution
cave
cavern
cavern_out
cave_in
cavil
cavort
caw
cease
cede
celebrate
cell_phone
cement
cense
censor
censure
census
center
center_on
center_punch
centralise
centralize
centre
centrifugate
centrifuge
cere
cerebrate
certificate
certify
cha-cha
chafe
chaff
chaffer
chagrin
chain
chain-smoke
chain_up
chair
chairman
chalk
chalk_out
chalk_up
challenge
chamber
chamfer
champ
champion
chance
chance_on
chance_upon
chandelle
change
change_by_reversal
change_course
change_form
change_hands
change_integrity
change_intensity
change_magnitude
change_over
change_owners
change_posture
change_shape
change_state
change_surface
change_taste
channel
channel-surf
channelise
channelize
chant
chap
chaperon
chaperone
char
character
characterise
characterize
charcoal
charge
charge_up
chariot
charleston
charm
chart
charter
chase
chase_after
chase_away
chasse
chasten
chastise
chat
chatter
chat_up
chauffeur
chaw
cheapen
cheat
cheat_on
check
checker
checkmate
checkrow
check_in
check_into
check_off
check_out
check_over
check_up_on
cheek
cheep
cheer
cheerlead
cheer_up
cheese
chelate
chemisorb
cheque
chequer
cherish
chevvy
chevy
chew
chew_out
chew_over
chew_the_fat
chew_up
chicane
chicken-fight
chickenfight
chicken_out
chide
child-proof
childproof
chill
chill_out
chime
chime_in
chin
chine
chink
chin_up
chip
chip_at
chip_away
chip_away_at
chip_in
chip_off
chirk
chirk_up
chiromance
chirp
chirr
chirrup
chisel
chisel_in
chit-chat
chitchat
chitter
chivvy
chivy
chlorinate
chloroform
chock
chock_up
choir
choke
choke_back
choke_down
choke_off
choke_up
chomp
chondrify
choose
choose_up
chop
chop_down
chop_off
chop_up
chord
choreograph
chortle
chorus
chouse
christen
christianise
christianize
chrome
chromium-plate
chronicle
chronologise
chronologize
chuck
chuckle
chuck_out
chuck_up_the_sponge
chuff
chug
chum_up
chunk
church
churn
churn_out
churn_up
churr
chute
cicatrise
cicatrize
cinch
cinematise
cinematize
cipher
circle
circle_around
circle_round
circuit
circularise
circularize
circulate
circumambulate
circumcise
circumfuse
circumnavigate
circumscribe
circumstantiate
circumvallate
circumvent
circumvolute
circumvolve
cite
citify
citrate
civilise
civilize
clabber
clack
claim
clam
clamber
clamor
clamour
clamp
clamp_down
clam_up
clang
clangor
clangour
clank
clap
clapboard
clapperclaw
clap_on
clap_together
clap_up
claret
clarify
clarion
clash
clasp
class
classicise
classicize
classify
clatter
claver
claw
claxon
clean
cleanse
clean_house
clean_out
clean_up
clear
clear-cut
clear_away
clear_off
clear_out
clear_the_air
clear_the_throat
clear_up
cleat
cleave
clench
clerk
clew
click
click_off
click_open
climax
climb
climb_down
climb_on
climb_up
clinch
cling
cling_to
clink
clinker
clip
clitter
cloak
clobber
clock
clock_in
clock_off
clock_on
clock_out
clock_up
clog
clog_up
cloister
clomp
clone
clop
close
closet
close_down
close_in
close_off
close_out
close_up
closure
clot
clothe
cloture
cloud
cloud_over
cloud_up
clout
clown
clown_around
cloy
club
cluck
clue
clue_in
clump
clunk
cluster
clutch
clutter
clutter_up
co-author
co-educate
co-occur
co-occur_with
co-opt
co-sign
co-star
co-vary
coach
coact
coagulate
coal
coalesce
coapt
coarsen
coast
coat
coax
cobble
cobblestone
cobble_together
cobble_up
cocainise
cocainize
cock
cocker
cockle
cock_up
coconspire
cocoon
cod
coddle
code
codify
coeducate
coerce
coexist
coffin
cog
coggle
cogitate
cognise
cognize
cohabit
cohere
coif
coiffe
coiffure
coil
coin
coincide
coinsure
coke
cold-cream
cold-shoulder
coldcock
coldwork
cold_work
collaborate
collapse
collar
collate
collateralize
collect
collectivise
collectivize
collide
collide_with
colligate
collimate
collocate
collocate_with
collogue
collude
colly
colonise
colonize
color
colorcast
colorise
colorize
color_in
colour
colourise
colourize
colour_in
comb
combat
combine
combust
comb_out
come
come_about
come_across
come_after
come_alive
come_along
come_apart
come_around
come_away
come_back
come_before
come_by
come_close
come_down
come_forth
come_forward
come_home
come_in
come_into
come_into_being
come_in_for
come_in_handy
come_near
come_off
come_of_age
come_on
come_out
come_out_of_the_closet
come_over
come_round
come_short
come_through
come_to
come_together
come_to_grips
come_to_hand
come_to_life
come_to_light
come_to_mind
come_to_the_fore
come_up
come_upon
come_up_to
come_with
comfit
comfort
command
commandeer
commemorate
commence
commend
comment
commentate
commercialise
commercialize
comminate
commingle
comminute
commiserate
commission
commit
commit_suicide
commix
commove
communalise
communalize
commune
communicate
communise
communize
commutate
commute
compact
companion
company
compare
comparison-shop
compart
compartmentalise
compartmentalize
compass
compassionate
compel
compensate
compere
compete
compile
complain
complect
complement
complete
complexify
complexion
complicate
compliment
complot
comply
comport
compose
compost
compound
comprehend
compress
comprise
compromise
compute
computerise
computerize
con
concatenate
conceal
concede
conceive
conceive_of
concenter
concentrate
concentrate_on
concentre
conceptualise
conceptualize
concern
concert
concertina
concertise
concertize
conciliate
conclude
concoct
concord
concrete
concretise
concretize
concur
concuss
condemn
condense
condescend
condition
condole
condole_with
condone
conduce
conduct
cone
confab
confabulate
confect
confection
confederate
confer
confer_with
confess
confide
configure
confine
confirm
confiscate
conflagrate
conflate
conflict
conform
conform_to
confound
confront
confuse
confute
conga
conge
congeal
congee
congest
conglobate
conglobe
conglomerate
conglutinate
congratulate
congregate
conjecture
conjoin
conjugate
conjure
conjure_up
conk
conk_out
conn
connect
connive
connive_at
connote
conquer
conscript
consecrate
consent
conserve
consider
consign
consist
consociate
console
consolidate
consonate
consort
conspire
constellate
consternate
constipate
constitute
constitutionalise
constitutionalize
constrain
constrict
constringe
construct
construe
construe_with
consubstantiate
consult
consume
consummate
contact
contain
containerise
containerize
contaminate
contemn
contemplate
contemporise
contemporize
contend
content
contest
continue
contort
contour
contract
contract_in
contract_out
contradance
contradict
contradistinguish
contraindicate
contrast
contravene
contra_danse
contredanse
contribute
contrive
control
controvert
contuse
convalesce
convect
convene
conventionalise
conventionalize
converge
converse
convert
convey
convict
convince
convoke
convolute
convolve
convoy
convulse
coo
cooccur
cooccur_with
cook
cook_out
cook_up
cool
cool_down
cool_it
cool_off
cool_one's_heels
cooper
cooperate
coop_in
coop_up
coordinate
cop
cope
cope_with
copolymerise
copolymerize
copper
copper-bottom
copulate
copy
copyedit
copyread
copyright
copy_out
cop_out
coquet
coquette
corbel
cord
cordon_off
corduroy
core
core_out
cork
corkscrew
cork_up
corn
corner
cornice
coronate
corrade
corral
correct
correlate
correspond
corroborate
corrode
corrugate
corrupt
corset
coruscate
cosh
cosign
cosponsor
cosset
cost
costume
cotton
cotton_on
cotton_up
couch
cough
cough_out
cough_up
counsel
count
countenance
counter
counter-drill
counteract
counterattack
counterbalance
counterchallenge
counterchange
countercheck
counterclaim
counterfeit
countermand
countermarch
countermine
counterplot
counterpoint
counterpoise
counterpose
countersign
countersink
counterstrike
countervail
counterweight
country-dance
count_down
count_off
count_on
count_out
couple
couple_on
couple_up
course
court
court-martial
court_favor
court_favour
covenant
cover
cover_for
cover_up
covet
cow
cower
cowhide
cowl
cox
cozen
cozy_up
crab
crack
crackle
crack_down
crack_up
cradle
craft
cram
cramp
cranch
crane
crank
crank_out
crank_up
crap
crape
crap_up
crash
crash-dive
crash_land
crate
craunch
crave
crawfish
crawfish_out
crawl
crawl_in
crayon
craze
creak
cream
cream_off
crease
create
create_by_mental_act
create_from_raw_material
create_from_raw_stuff
create_mentally
create_verbally
credit
creep
creep_in
creep_up
cremate
crenel
crenelate
crenellate
creolize
creosote
crepe
crepitate
crescendo
crest
crew
crib
crick
cricket
criminalise
criminalize
criminate
crimp
crimson
cringe
crinkle
cripple
crisp
crispen
crisscross
criticise
criticize
critique
croak
crochet
crock
crock_up
cronk
crook
croon
crop
crop_out
crop_up
croquet
cross
cross-check
cross-dress
cross-fertilise
cross-fertilize
cross-file
cross-index
cross-link
cross-pollinate
cross-refer
crossbreed
crosscut
crosshatch
crossruff
cross_examine
cross_off
cross_oneself
cross_out
cross_question
crouch
crow
crowd
crowd_out
crowd_together
crown
crucify
cruise
crumb
crumble
crump
crumple
crunch
crusade
crush
crush_out
crust
cry
crystalise
crystalize
crystallise
crystallize
cry_for
cry_out
cry_out_for
cub
cube
cuckold
cuckoo
cuddle
cudgel
cue
cuff
cull
cull_out
culminate
cultivate
culture
cumber
cumulate
cup
curb
curdle
cure
curl
curl_up
curry
currycomb
curry_favor
curry_favour
curse
curtail
curtain
curtain_off
curtsey
curtsy
curve
curvet
cushion
cuss
custom-make
customise
customize
cut
cutinize
cut_across
cut_away
cut_back
cut_corners
cut_down
cut_in
cut_into
cut_off
cut_out
cut_short
cut_through
cut_to
cut_to_ribbons
cut_up
cybernate
cycle
cycle_on
cyclostyle
cypher
dab
dabble
dado
daisy-chain
dally
dam
damage
damascene
damn
damp
dampen
dam_up
dance
dandify
dandle
dangle
dapple
dare
darken
darn
dart
dash
dash_down
dash_off
date
date-mark
dateline
datemark
date_back
date_from
date_stamp
daub
daunt
dawdle
dawn
daydream
daze
dazzle
de-access
de-aerate
de-emphasise
de-emphasize
de-energise
de-energize
de-escalate
de-ice
de-iodinate
de-ionate
deaccession
deactivate
deaden
deaerate
deaf
deafen
deal
deal_out
deaminate
deaminize
debar
debark
debase
debate
debauch
debilitate
debit
debone
debouch
debrief
debug
debunk
debut
decaffeinate
decalcify
decamp
decant
decapitate
decarbonate
decarbonise
decarbonize
decarboxylate
decarburise
decarburize
decay
decease
deceive
decelerate
decentralise
decentralize
decerebrate
decertify
dechlorinate
decide
decimalise
decimalize
decimate
decipher
deck
deck_out
deck_up
declaim
declare
declare_oneself
declassify
declaw
decline
declutch
decoct
decode
decoke
decollate
decolonise
decolonize
decolor
decolorise
decolorize
decolour
decolourise
decolourize
decommission
decompose
decompress
deconcentrate
deconsecrate
deconstruct
decontaminate
decontrol
decorate
decorticate
decouple
decoy
decrease
decree
decrepitate
decrescendo
decriminalise
decriminalize
decry
decrypt
decussate
dedicate
dedifferentiate
deduce
deduct
deed_over
deem
deep-dye
deep-fat-fry
deep-fry
deep-six
deepen
deep_freeze
deface
defalcate
defame
defang
defat
default
default_on
defeat
defecate
defect
defeminise
defeminize
defend
defenestrate
defer
defervesce
defibrillate
defibrinate
defile
define
deflagrate
deflate
deflect
deflower
defog
defoliate
deforest
deform
defraud
defray
defrock
defrost
defuse
defy
degas
degauss
degenerate
deglaze
deglycerolise
deglycerolize
degrade
degrease
degust
dehisce
dehorn
dehumanise
dehumanize
dehumidify
dehydrate
dehydrogenate
deice
deify
deign
deionize
deject
delay
delegate
delete
deliberate
delight
delimit
delimitate
delineate
deliquesce
delist
deliver
deliver_the_goods
delocalize
delouse
delude
deluge
delve
demagnetise
demagnetize
demand
demarcate
demasculinise
demasculinize
dematerialise
dematerialize
demean
demilitarise
demilitarize
demineralise
demineralize
demise
demist
demo
demob
demobilise
demobilize
democratise
democratize
demodulate
demolish
demonetise
demonetize
demonise
demonize
demonstrate
demoralise
demoralize
demote
demulsify
demur
demyelinate
demystify
demythologise
demythologize
denationalise
denationalize
denaturalise
denaturalize
denature
denazify
denigrate
denitrify
denominate
denote
denounce
dent
denudate
denude
deny
deodorise
deodorize
deodourise
deoxidise
deoxidize
deoxygenate
depart
depend
depend_on
depend_upon
depersonalise
depersonalize
depict
depilate
deplane
deplete
deplore
deploy
deplumate
deplume
depolarise
depolarize
depone
depopulate
deport
depose
deposit
deprave
deprecate
depreciate
depress
depressurise
depressurize
deprive
depute
deputise
deputize
deracinate
derail
derange
derate
derecognise
derecognize
deregulate
derequisition
derestrict
deride
derive
derogate
desacralize
desalinate
desalinise
desalinize
desalt
descale
descant
descant_on
descend
describe
descry
desecrate
desegregate
desensitise
desensitize
desert
deserve
desex
desexualise
desexualize
desiccate
design
designate
desire
desist
desolate
desorb
despair
despatch
despise
despoil
despond
desquamate
destabilise
destabilize
destain
destalinise
destalinize
destine
destress
destroy
destruct
desulfurize
desulphurize
desynchronise
desynchronize
detach
detail
detain
detect
deter
deterge
deteriorate
determine
detest
dethaw
dethrone
detick
detonate
detour
detox
detoxicate
detoxify
detract
detrain
detransitivise
detransitivize
detribalise
detribalize
detusk
devaluate
devalue
devastate
devein
develop
deviate
devil
devilise
devilize
devise
devitalise
devitalize
devitrify
devoice
devolve
devolve_on
devote
devour
diabolise
diabolize
diagnose
diagonalise
diagonalize
diagram
dial
dialyse
dialyze
diazotize
dibble
dice
dichotomise
dichotomize
dicker
dictate
didder
diddle
die
diet
die_away
die_back
die_down
die_hard
die_off
die_out
differ
differentiate
diffract
diffuse
dig
digest
digitalise
digitalize
digitise
digitize
dignify
digress
dig_in
dig_into
dig_out
dig_up
dike
dilapidate
dilate
dilly-dally
dillydally
dilute
dim
dimension
diminish
dimple
din
dine
dine_in
dine_out
ding
dingdong
dinge
dip
diphthongise
diphthongize
dip_into
dip_solder
direct
dirty
disable
disabuse
disaccord
disadvantage
disaffect
disafforest
disagree
disagree_with
disallow
disambiguate
disappear
disappoint
disapprove
disarm
disarrange
disarray
disarticulate
disassemble
disassociate
disavow
disband
disbar
disbelieve
disbud
disburden
disburse
disc-jockey
discard
discase
discern
discerp
discharge
discipline
disclaim
disclose
disco
discolor
discolorise
discolorize
discolour
discolourise
discombobulate
discomfit
discommode
discompose
disconcert
disconnect
discontent
discontinue
discord
discount
discountenance
discourage
discourse
discover
discredit
discriminate
discuss
disdain
disembark
disembarrass
disembody
disembowel
disembroil
disenable
disenchant
disencumber
disenfranchise
disengage
disentangle
disestablish
disesteem
disfavor
disfavour
disfigure
disforest
disfranchise
disgorge
disgrace
disgruntle
disguise
disgust
dish
disharmonize
dishearten
dishevel
dishonor
dishonour
dish_out
dish_the_dirt
dish_up
disillusion
disincarnate
disincline
disinfect
disinfest
disinherit
disintegrate
disinter
disinvest
disinvolve
disjoin
disjoint
disk
disk-jockey
dislike
dislocate
dislodge
dismantle
dismay
dismember
dismiss
dismount
disobey
disoblige
disorder
disorganise
disorganize
disorient
disorientate
disown
disparage
dispatch
dispel
dispense
dispense_with
disperse
dispirit
displace
display
displease
displume
disport
dispose
dispose_of
dispossess
dispread
disprove
dispute
disqualify
disquiet
disregard
disrespect
disrobe
disrupt
diss
dissatisfy
dissect
dissemble
disseminate
dissent
dissertate
dissever
dissimilate
dissimulate
dissipate
dissociate
dissolve
dissonate
dissuade
distance
distemper
distend
distil
distill
distinguish
distort
distract
distrain
distress
distribute
district
distrust
disturb
disunify
disunite
ditch
dither
ditto
divagate
divaricate
dive
dive-bomb
diverge
diversify
divert
divest
divide
divine
divorce
divulge
divvy_up
dizen
dizzy
dj
do
dock
docket
doctor
doctor_up
document
dodder
dodge
doff
dog
dogfight
dogmatise
dogmatize
dogsled
dole_out
doll_up
domesticate
domesticise
domesticize
domicile
domiciliate
dominate
domineer
don
donate
dong
doodle
doom
dope
dope_off
dope_up
dose
doss
doss_down
dot
dote
double
double-check
double-date
double-glaze
double-park
double-space
double-team
double_back
double_birdie
double_bogey
double_crochet
double_cross
double_dye
double_over
double_stitch
double_tongue
double_up
doubt
douche
douse
dovetail
dower
down
downgrade
download
downplay
downsize
dowse
doze
doze_off
do_away_with
do_a_job_on
do_by
do_drugs
do_good
do_in
do_it
do_justice
do_one's_best
do_the_dishes
do_the_honors
do_up
do_well
do_well_by
do_work
draft
drag
draggle
dragoon
drag_a_bunt
drag_down
drag_in
drag_on
drag_one's_feet
drag_one's_heels
drag_out
drag_through_the_mud
drag_up
drain
drain_the_cup
dramatise
dramatize
drape
draught
draw
drawl
draw_and_quarter
draw_away
draw_a_bead_on
draw_a_blank
draw_a_line
draw_back
draw_close
draw_in
draw_near
draw_off
draw_out
draw_rein
draw_the_line
draw_together
draw_up
dread
dream
dream_up
dredge
dredge_up
drench
dress
dress_down
dress_out
dress_ship
dress_up
dribble
drift
drift_apart
drift_away
drift_off
drill
drill_in
drink
drink_down
drink_in
drink_up
drip
drip-dry
drive
drivel
drive_around
drive_away
drive_back
drive_home
drive_in
drive_off
drive_out
drive_up
drizzle
drone
drone_on
drool
drool_over
droop
drop
drop-kick
dropforge
dropkick
drop_anchor
drop_away
drop_a_line
drop_back
drop_behind
drop_by
drop_by_the_wayside
drop_dead
drop_down
drop_in
drop_like_flies
drop_off
drop_one's_serve
drop_open
drop_out
drop_the_ball
drown
drown_out
drowse
drowse_off
drub
drudge
drug
drum
drum_out
drum_up
dry
dry-dock
dry-nurse
dry-rot
dry-wall
drydock
dry_clean
dry_out
dry_up
dub
duck
duel
dulcify
dulcorate
dull
dumbfound
dummy
dummy_up
dump
dun
dung
dunk
dupe
duplex
duplicate
dusk
dust
dwarf
dwell
dwell_on
dwindle
dwindle_away
dwindle_down
dye
dyke
dynamise
dynamite
dynamize
e-mail
eagle
earmark
earn
earth
earth_up
ease
ease_off
ease_up
eat
eat_at
eat_away
eat_in
eat_into
eat_on
eat_out
eat_up
eavesdrop
ebb
ebb_away
ebb_down
ebb_off
ebb_out
ebonise
ebonize
echo
eclipse
economise
economize
eddy
edge
edge_in
edge_up
edify
edit
editorialise
editorialize
edit_out
educate
educe
edulcorate
eff
efface
effect
effectuate
effeminise
effeminize
effervesce
effloresce
effuse
egest
egg
egg_on
egotrip
egress
ejaculate
eject
eke_out
elaborate
elapse
elate
elbow
elect
electioneer
electrify
electrocute
electroplate
elegise
elegize
elevate
elicit
elide
eliminate
elocute
elongate
elope
elucidate
elude
elute
emaciate
email
emanate
emancipate
emasculate
embalm
embank
embargo
embark
embark_on
embarrass
embattle
embed
embellish
embezzle
embitter
emblazon
embody
embolden
emboss
embower
embrace
embrangle
embrittle
embrocate
embroider
embroil
embrown
emcee
emend
emerge
emigrate
emit
emote
empale
empanel
empathise
empathize
emphasise
emphasize
emplace
emplane
employ
empower
empty
empurple
emulate
emulsify
enable
enact
enamel
enamor
enamour
encamp
encapsulate
encase
enchain
enchant
encipher
encircle
enclose
enclothe
encode
encompass
encore
encounter
encourage
encrimson
encroach
encroach_upon
encrust
encrypt
encumber
end
endanger
endear
endeavor
endeavour
endorse
endow
endue
endure
end_up
energise
energize
enervate
enfeeble
enfeoff
enfilade
enfold
enforce
enfranchise
engage
engender
engild
engineer
englut
engorge
engraft
engrave
engross
engulf
enhance
enjoin
enjoy
enkindle
enlace
enlarge
enlighten
enlist
enliven
enmesh
ennoble
enounce
enplane
enquire
enrage
enrapture
enrich
enrobe
enrol
enroll
ensconce
enshrine
enshroud
ensile
ensky
enslave
ensnare
ensnarl
ensue
ensure
entail
entangle
enter
entertain
enter_upon
enthral
enthrall
enthrone
enthuse
entice
entitle
entomb
entrain
entrance
entrap
entreat
entrench
entrust
entwine
enucleate
enumerate
enunciate
envelop
envenom
environ
envisage
envision
envy
enwrap
epilate
epitomise
epitomize
epoxy
equal
equalise
equalize
equate
equilibrate
equilibrise
equilibrize
equip
equivocate
eradicate
erase
erect
erode
eroticize
err
eruct
erupt
escalade
escalate
escallop
escape
escape_from
eschew
escort
espouse
espy
essay
establish
esteem
esterify
estimate
estivate
estrange
etch
eternalise
eternalize
eternise
eternize
etherealize
etherialise
etherify
etherise
etherize
etiolate
etymologise
etymologize
eulogise
eulogize
euphemise
euphemize
europeanise
europeanize
evacuate
evade
evaluate
evanesce
evangelise
evangelize
evaporate
even
eventuate
even_off
even_out
even_up
evert
evict
evidence
evince
eviscerate
evoke
evolve
exacerbate
exact
exaggerate
exalt
examine
exasperate
excavate
exceed
excel
excel_at
except
excerpt
exchange
excise
excite
exclaim
exclude
excogitate
excommunicate
excoriate
excrete
excruciate
exculpate
excuse
execrate
execute
exemplify
exempt
exenterate
exercise
exert
exfoliate
exhale
exhaust
exhibit
exhilarate
exhort
exhume
exile
exist
exit
exonerate
exorcise
exorcize
expand
expatiate
expatriate
expect
expectorate
expedite
expel
expend
expense
experience
experiment
expiate
expire
explain
explicate
explode
explode_a_bombshell
exploit
explore
export
expose
exposit
expostulate
expound
express
express-mail
express_emotion
express_feelings
express_joy
express_mirth
expropriate
expunge
expurgate
exsert
exsiccate
extemporise
extemporize
extend
extend_oneself
extend_to
extenuate
exteriorise
exteriorize
exterminate
externalise
externalize
extinguish
extirpate
extol
extort
extract
extradite
extrapolate
extravasate
extricate
extrude
exuberate
exudate
exude
exult
exuviate
eye
eyeball
eyewitness
fabricate
face
face-harden
face-lift
face_off
face_the_music
face_up
facilitate
facsimile
factor
factorise
factorize
factor_analyse
factor_analyze
factor_in
factor_out
fade
fade_away
fade_out
fag
faggot
faggot_up
fagot
fag_out
fail
faint
fair
fake
falcon
fall
fall_all_over
fall_apart
fall_asleep
fall_away
fall_back
fall_behind
fall_by_the_wayside
fall_down
fall_flat
fall_for
fall_from_grace
fall_in
fall_into
fall_into_place
fall_in_line
fall_in_love
fall_off
fall_open
fall_out
fall_over
fall_over_backwards
fall_short
fall_short_of
fall_through
fall_under
fall_upon
falsify
falter
familiarise
familiarize
famish
fan
fancify
fancy
fancy_up
fantasise
fantasize
fantasy
fan_out
farce
fare
farm
farm_out
farrow
fart
fascinate
fashion
fast
fasten
fasten_on
fast_dye
fat
fate
father
fathom
fatigue
fatten
fatten_out
fatten_up
fault
favor
favour
fawn
fax
faze
fear
feast
feast_one's_eyes
feather
featherbed
feather_one's_nest
feature
fecundate
federalise
federalize
federate
fee
fee-tail
feed
feed_back
feed_in
feed_on
feed_upon
feel
feel_for
feel_like
feel_like_a_million
feel_like_a_million_dollars
feel_out
feign
feint
felicitate
fell
fellate
felt
felt_up
feminise
feminize
fence
fence_in
fend
fend_for
fend_off
ferment
ferret
ferret_out
ferry
fertilise
fertilize
fess_up
fester
festinate
festoon
fetch
fetch_up
fete
fetishize
fetter
fettle
feud
feudalize
fib
fibrillate
fictionalise
fictionalize
fiddle
fiddle_with
fidget
field
field-test
fight
fight_back
fight_down
fight_off
figure
figure_out
figure_skate
fig_out
fig_up
filch
file
filet
file_away
file_in
file_out
filiate
filibuster
filigree
fill
fillet
fill_again
fill_in
fill_out
fill_the_bill
fill_up
film
film-make
film_over
filter
filter_out
filtrate
fin
finagle
finalise
finalize
finance
financier
find
find_fault
find_oneself
find_out
fine
fine-tune
finedraw
finger
finger-paint
finger-spell
fingerprint
fingerspell
finish
finish_off
finish_out
finish_up
fink
fire
firebomb
fireproof
fire_up
firm
firm_up
fish
fishtail
fissure
fistfight
fit
fit_in
fit_out
fit_the_bill
fix
fixate
fix_up
fizz
fizzle
fizzle_out
flabbergast
flag
flagellate
flag_down
flail
flake
flake_off
flake_out
flambe
flame
flame_up
flank
flap
flap_down
flare
flare_out
flare_up
flash
flash-freeze
flash_back
flat-hat
flatten
flatten_out
flatter
flaunt
flavor
flavour
flaw
flay
fleck
fledge
flee
fleece
fleer
fleet
flense
flesh
flesh_out
flex
flick
flicker
flight
flim-flam
flinch
fling
fling_off
flip
flip-flop
flip_one's_lid
flip_one's_wig
flip_out
flip_over
flirt
flirt_with
flit
flitter
float
flocculate
flock
flog
flood
floodlight
flood_in
flood_out
floor
flop
floss
flounce
flounder
flour
flourish
flout
flow
flower
flow_away
flow_from
flow_off
flow_out
flub
fluctuate
fluff
fluff_up
flummox
flump
flump_down
flunk
fluoresce
fluoridate
fluoridise
fluoridize
flurry
flush
flush_down
flush_it
fluster
flute
flutter
flux
fly
fly-fish
flyfish
fly_blind
fly_by
fly_contact
fly_high
fly_in_the_face_of
fly_in_the_teeth_of
fly_off_the_handle
fly_on
fly_open
fly_the_coop
foal
foam
foam_at_the_mouth
fob
fob_off
focalise
focalize
focus
focus_on
fodder
fog
fog_up
foil
foist
foist_off
fold
fold_up
foliate
folk_dance
follow
follow_out
follow_suit
follow_through
follow_up
follow_up_on
foment
fondle
fool
foolproof
fool_around
fool_away
foot
footle
footnote
footslog
foot_up
forage
foray
foray_into
forbear
forbid
force
force-feed
force-land
force_back
force_out
ford
forearm
forebode
forecast
foreclose
foredate
foredoom
forefend
foregather
forego
foreground
foreknow
foreordain
foresee
foreshadow
foreshorten
foreshow
forest
forestall
foreswear
foretell
forewarn
forfeit
forfend
forgather
forge
forget
forgive
forgo
fork
fork_out
fork_over
fork_up
form
formalise
formalize
format
formicate
formularise
formularize
formulate
form_bubbles
fornicate
forsake
forswear
fort
fortify
fort_up
forward
fossilise
fossilize
foster
foul
foul_out
foul_up
found
founder
fowl
fox
foxhunt
foxtrot
fraction
fractionate
fracture
fragment
fragmentise
fragmentize
frame
frame_in
frame_up
franchise
frank
frap
fraternise
fraternize
fray
frazzle
freak
freak_out
freckle
free
free-associate
free-base
freelance
freeload
freewheel
freeze
freeze-dry
freeze_down
freeze_off
freeze_out
freight
french
french-fry
frenchify
frequent
fresco
freshen
freshen_up
fress
fret
fricassee
fright
frighten
frighten_away
frighten_off
frig_around
fringe
frisk
fritter
fritter_away
frivol
frivol_away
frizz
frizzle
frock
frog
frogmarch
frolic
front
frost
frost_over
froth
froth_at_the_mouth
frown
frown_on
frown_upon
fructify
fruit
frustrate
fry
ftp
fuck
fuck_off
fuck_up
fuddle
fudge
fudge_together
fuel
fulfil
fulfill
full
fullback
fulminate
fumble
fume
fumigate
function
fund
fund-raise
fundraise
fund_raise
funk
funnel
furbish
furbish_up
furcate
furl
furlough
furnish
furrow
further
fuse
fusillade
fuss
fustigate
g.i.
gab
gabble
gad
gag
gage
gaggle
gain
gainsay
gain_ground
gain_vigor
gall
gallivant
gallop
galumph
galvanise
galvanize
gamble
gambol
game
gang
gang-rape
gangrene
gang_up
gaol
gap
gape
garage
garb
garbage_down
garble
garden
gargle
garland
garment
garner
garnish
garnishee
garotte
garrison
garrote
garrotte
garter
gas
gasconade
gash
gasify
gasp
gas_up
gate
gate-crash
gather
gather_in
gather_up
gauffer
gauge
gawk
gawp
gaze
gazette
gazump
gear
gear_up
gee
gel
gelatinise
gelatinize
geld
geminate
general
generalise
generalize
generate
gentle
gentrify
genuflect
germinate
gerrymander
gestate
gesticulate
gesture
get
get_about
get_across
get_ahead
get_along
get_along_with
get_around
get_around_to
get_at
get_away
get_a_line
get_a_load
get_a_look
get_a_noseful
get_a_whiff
get_back
get_behind
get_by
get_cracking
get_down
get_dressed
get_even
get_going
get_hitched_with
get_hold
get_hold_of
get_in
get_into
get_in_touch
get_it
get_it_on
get_laid
get_married
get_moving
get_off
get_off_the_ground
get_on
get_one's_lumps
get_onto
get_on_with
get_out
get_over
get_rid_of
get_rolling
get_started
get_stuck
get_the_best
get_the_better_of
get_the_goods
get_the_hang
get_the_jump
get_the_picture
get_through
get_to
get_together
get_to_grips
get_under_one's_skin
get_up
get_weaving
get_well
get_wind
get_wise
get_word
get_worse
geyser
ghettoise
ghettoize
ghost
ghostwrite
gi
gibber
gibbet
gibe
gift
gift-wrap
giggle
gild
gild_the_lily
gimp
gin
ginger
ginger_up
gip
gird
girdle
girth
give
give-up_the_ghost
give_and_take
give_away
give_a_damn
give_a_hang
give_a_hoot
give_back
give_birth
give_care
give_chase
give_ear
give_forth
give_full_measure
give_in
give_it_a_try
give_it_a_whirl
give_it_the_deep_six
give_notice
give_off
give_one's_best
give_out
give_rise
give_suck
give_thanks
give_the_axe
give_the_bounce
give_the_eye
give_the_gate
give_the_glad_eye
give_the_once_over
give_the_sack
give_tongue_to
give_up
give_vent
give_voice
give_way
glaciate
gladden
glamorise
glamorize
glamour
glamourise
glamourize
glam_up
glance
glance_over
glare
glass
glass_in
glass_over
glaze
glaze_over
gleam
glean
glide
glide-bomb
glide_by
glimmer
glimpse
glint
glissade
glisten
glitter
gloat
globalise
globalize
globe-trot
glom
glorify
glory
gloss
gloss_over
glow
glower
glue
glug
glut
gluttonise
gluttonize
glycerolise
glycerolize
gnarl
gnash
gnaw
gnaw_at
go
goad
gobble
gobble_up
goffer
goggle
gold-plate
goldbrick
goldplate
gold_plate
golf
gong
goof
goof-proof
goofproof
google
goose
goose_step
gore
gorge
gormandise
gormandize
gossip
gouge
gouge_out
gourmandize
govern
gown
go_about
go_across
go_after
go_against
go_ahead
go_all_out
go_along
go_around
go_away
go_a_long_way
go_back
go_back_on
go_bad
go_ballistic
go_by
go_deep
go_down
go_down_on
go_dutch
go_far
go_for
go_forth
go_forward
go_for_broke
go_home
go_in
go_into
go_off
go_off_at_half-cock
go_off_half-cocked
go_on
go_out
go_over
go_past
go_steady
go_through
go_through_the_motions
go_to
go_to_bed
go_to_pieces
go_to_pot
go_to_sleep
go_to_the_dogs
go_to_war
go_under
go_up
go_with
go_wrong
grab
grace
gradate
grade
graduate
graft
grain
grandstand
grant
granulate
graph
grapple
grasp
grass
grass_over
grate
gratify
grave
gravel
gravitate
gray
graze
grease
grease_one's_palms
green
greet
grey
griddle
grieve
grill
grimace
grime
grin
grind
grind_away
grind_down
grind_out
grind_to_a_halt
grip
gripe
grit
grizzle
groak
groan
groin
grok
groom
groove
grope
grope_for
gross
gross_out
grouch
ground
ground_out
group
grouse
grout
grovel
grow
growl
grow_over
grow_up
grub
grubstake
grub_out
grub_up
grudge
grumble
grunt
grunt-hoot
gruntle
guarantee
guard
guess
guesstimate
guffaw
guggle
guide
guide_on
guillotine
gull
gulp
gum
gum_up
gun
gun_down
gurgle
gush
gussy_up
gut
gutter
guttle
guy
guzzle
gybe
gyp
gyrate
habilitate
habit
habituate
hack
hackle
hack_on
had_best
haemagglutinate
haggle
hail
hale
halloo
hallow
hallucinate
halt
halter
halve
ham
hammer
hammer_in
hammer_out
hamper
hamstring
ham_it_up
hand
hand-build
hand-dye
hand-pick
hand-wash
handbuild
handcolor
handcolour
handcraft
handcuff
handicap
handle
handle_with_kid_gloves
handstamp
handwash
handwrite
hand_down
hand_out
hand_over
hang
hang_around
hang_back
hang_by_a_hair
hang_by_a_thread
hang_glide
hang_in
hang_on
hang_out
hang_together
hang_up
hanker
hap
happen
happen_upon
harangue
harass
harbinger
harbor
harbour
harden
hard_surface
hare
hark
harken
hark_back
harlequin
harm
harmonise
harmonize
harness
harp
harpoon
harrow
harry
harshen
harsh_on
harvest
hash
hash_out
hash_over
hasp
hassle
hasten
hat
hatch
hatchel
hate
haul
haul_away
haul_off
haul_up
haunt
have
have-to_doe_with
have_a_ball
have_a_bun_in_the_oven
have_a_fit
have_a_go
have_a_good_time
have_a_go_at_it
have_a_look
have_down
have_got
have_intercourse
have_in_mind
have_it_away
have_it_coming
have_it_off
have_kittens
have_on
have_sex
have_the_best
have_words
have_young
haw
hawk
hay
hazard
haze
haze_over
head
headbutt
headline
headquarter
head_for_the_hills
head_home
head_off
head_up
heal
heap
heap_up
hear
hearken
hearten
hear_out
heat
heat_up
heave
heave_up
heckle
hectograph
hector
hedge
hedgehop
hedge_in
hee-haw
heed
heel
heft
heft_up
heighten
heist
heliograph
helm
help
help_oneself
help_out
hem
hemagglutinate
hemorrhage
hemstitch
hem_and_haw
hem_in
hen-peck
henna
herald
herd
hero-worship
hesitate
heterodyne
hew
hew_out
hex
hibachi
hibernate
hiccough
hiccup
hide
hide_out
hie
higgle
high-tail
highjack
highlight
hightail
hightail_it
hijack
hike
hike_up
hill
hinder
hinge
hinge_on
hinge_upon
hint
hire
hire_out
hiss
hit
hitch
hitchhike
hitch_up
hit_home
hit_it_up
hit_the_books
hit_the_ceiling
hit_the_deck
hit_the_dirt
hit_the_hay
hit_the_jackpot
hit_the_roof
hit_the_sack
hive
hive_away
hive_off
hive_up
hoard
hoax
hob
hobble
hobnail
hobnob
hock
hoe
hog
hog-tie
hoist
hold
hold_back
hold_close
hold_dear
hold_down
hold_fast
hold_firm
hold_forth
hold_in
hold_off
hold_on
hold_one's_own
hold_open
hold_out
hold_over
hold_still_for
hold_sway
hold_the_line
hold_tight
hold_up
hold_water
hole
hole_out
hole_up
holiday
holler
holler_out
hollo
hollow
hollow_out
holystone
home
home-school
homer
homestead
home_in
homogenise
homogenize
homologise
homologize
hone
honey
honeycomb
honeymoon
honk
honor
honour
hood
hoodoo
hoodwink
hoof
hoof_it
hook
hook_on
hook_up
hook_up_with
hoop
hoot
hoover
hop
hop-skip
hope
hopple
hop_on
hop_out
hop_up
horn
hornswoggle
horn_in
horrify
horripilate
horse
horse-race
horse-trade
horseshoe
horsewhip
horse_around
hose
hose_down
hospitalise
hospitalize
host
hot-dog
hot-wire
hot-work
hotfoot
hot_up
hound
house
house-train
housebreak
houseclean
housekeep
hover
howl
huckster
huddle
huddle_together
hue
huff
hug
hugger_mugger
hulk
hull
hum
humanise
humanize
humble
humbug
humidify
humify
humiliate
humor
humour
hump
hunch
hunch_forward
hunch_over
hunger
hunker
hunker_down
hunt
hunt_down
hurdle
hurl
hurrah
hurry
hurt
hurtle
husband
hush
hush_up
husk
hustle
hybridise
hybridize
hydrate
hydrogen-bomb
hydrogenate
hydrolise
hydrolize
hydrolyse
hydrolyze
hydroplane
hygienise
hygienize
hymn
hype
hyperbolise
hyperbolize
hyperextend
hypertrophy
hyperventilate
hype_up
hyphen
hyphenate
hypnotise
hypnotize
hypophysectomise
hypophysectomize
hypostatise
hypostatize
hypothecate
hypothesise
hypothesize
ice
ice_over
ice_skate
ice_up
idealise
idealize
ideate
identify
idle
idolise
idolize
ignite
ignore
ill-treat
ill-use
illegalise
illegalize
illume
illuminate
illumine
illustrate
image
imagine
imbed
imbibe
imbricate
imbrue
imbue
imitate
immaterialise
immaterialize
immerse
immigrate
immingle
immix
immobilise
immobilize
immolate
immortalise
immortalize
immunise
immunize
immure
impact
impair
impale
impanel
impart
impeach
impede
impel
impend
imperil
impersonate
impinge
impinge_on
implant
implement
implicate
implode
implore
imply
import
importune
impose
impound
impoverish
imprecate
impregnate
impress
imprint
imprison
improve
improvise
improvize
impugn
impulse-buy
impute
inactivate
inaugurate
incandesce
incapacitate
incarcerate
incarnadine
incarnate
incase
incense
inch
incinerate
incise
incite
incline
inclose
include
incommode
inconvenience
inconvenience_oneself
incorporate
increase
incriminate
incrust
incubate
inculcate
inculpate
incur
incurvate
indemnify
indent
indenture
index
indicate
indict
indispose
indite
individualise
individualize
individuate
indoctrinate
indorse
induce
induct
indue
indulge
indurate
industrialise
industrialize
indwell
inebriate
infatuate
infect
infer
infest
infiltrate
infix
inflame
inflate
inflect
inflict
influence
inform
infract
infringe
infuriate
infuscate
infuse
ingeminate
ingest
ingraft
ingrain
ingratiate
ingurgitate
inhabit
inhale
inhere
inhere_in
inherit
inhibit
inhume
initial
initialise
initialize
initiate
inject
injure
ink
inlay
inmarry
innervate
innovate
inoculate
inosculate
input
inquire
inscribe
inseminate
insert
inset
insinuate
insist
insolate
inspan
inspect
inspire
inspirit
inspissate
instal
install
instance
instantiate
instigate
instil
instill
institute
institutionalise
institutionalize
instruct
instrument
instrumentate
insufflate
insulate
insult
insure
integrate
intend
intensify
inter
interact
interbreed
intercalate
intercede
intercept
interchange
intercommunicate
interconnect
interdepend
interdict
interest
interfere
interiorise
interiorize
interject
interlace
interlard
interleave
interlink
interlock
interlope
interlude
intermarry
intermediate
intermingle
intermit
intermix
intern
internalise
internalize
internationalise
internationalize
interpellate
interpenetrate
interpolate
interpose
interpret
interrelate
interrogate
interrupt
intersect
intersperse
interstratify
intertwine
intervene
interview
interweave
intimate
intimidate
intonate
intone
intoxicate
intransitivise
intransitivize
intrench
intrigue
introduce
introject
intromit
introspect
introvert
intrude
intrude_on
intrust
intubate
intuit
intumesce
intussuscept
inunct
inundate
inure
invade
invaginate
invalid
invalidate
inveigh
inveigle
invent
inventory
invert
invest
investigate
invigilate
invigorate
invite
invite_out
invoice
invoke
involve
inweave
iodinate
iodise
iodize
ionate
ionise
ionize
iridesce
irk
iron
iron_out
irradiate
irrigate
irritate
irrupt
islamise
islamize
island_hop
isolate
isomerise
isomerize
issue
issue_forth
italicise
italicize
itch
itemise
itemize
iterate
itinerate
jab
jabber
jack
jacket
jackknife
jacklight
jackrabbit
jack_off
jack_up
jactitate
jade
jag
jail
jam
jampack
jangle
japan
jar
jar_against
jaundice
jaunt
jaw
jawbone
jaywalk
jazz
jazz_around
jazz_up
jeer
jell
jellify
jelly
jeopardise
jeopardize
jerk
jerk_off
jest
jest_at
jet
jettison
jewel
jib
jibe
jig
jiggle
jilt
jimmy
jingle
jingle-jangle
jinx
jitterbug
jive
job
jockey
jog
joggle
join
joint
join_battle
join_forces
joke
jollify
jolly
jolly_along
jolly_up
jolt
josh
jostle
jot
jot_down
jounce
journey
joust
joy
joyride
jubilate
judder
judge
jug
juggle
juice_up
julienne
jumble
jump
jump-start
jumpstart
jump_for_joy
jump_off
jump_on
jump_out
junk
junket
junketeer
justify
jut
jut_out
juxtapose
kayak
kayo
keel
keel_over
keen
keep
keep_abreast
keep_an_eye_on
keep_apart
keep_away
keep_back
keep_company
keep_down
keep_going
keep_guard
keep_in
keep_in_line
keep_mum
keep_note
keep_off
keep_on
keep_one's_distance
keep_one's_eyes_off
keep_one's_eyes_open
keep_one's_eyes_peeled
keep_one's_eyes_skinned
keep_one's_hands_off
keep_one's_mouth_shut
keep_one's_nose_to_the_grindstone
keep_one's_shoulder_to_the_wheel
keep_open
keep_out
keep_pace
keep_quiet
keep_step
keep_tabs_on
keep_to_oneself
keep_track
keep_up
kennel
keratinise
keratinize
kern
key
keynote
key_out
kibbitz
kibitz
kibosh
kick
kick-start
kick_about
kick_around
kick_back
kick_down
kick_downstairs
kick_in
kick_off
kick_one's_heels
kick_out
kick_the_bucket
kick_up
kick_upstairs
kid
kidnap
kill
kill_off
kill_oneself
kindle
kink
kink_up
kip
kip_down
kiss
kit
kite
kitten
kit_out
kit_up
knap
knead
kneecap
kneel
knell
knife
knight
knit
knock
knock_about
knock_against
knock_back
knock_cold
knock_down
knock_off
knock_out
knock_over
knock_up
knot
know
know_apart
know_the_score
know_what's_going_on
know_what's_what
knuckle
knuckle_down
knuckle_under
kotow
kowtow
kvetch
label
labialise
labialize
labor
labour
lace
lacerate
lace_into
lace_up
lack
lacquer
lactate
ladder
lade
laden
ladle
lag
laicise
laicize
lallygag
lam
lamb
lambast
lambaste
lame
lament
laminate
lampoon
lam_into
lance
land
landscape
land_up
languish
lap
lapidate
lapidify
lapse
lap_up
lard
lark
lark_about
larn
larrup
lash
lash_out
lash_together
lasso
last
last_out
latch
latch_on
lateralize
lather
latinise
latinize
laud
laugh
laugh_at
laugh_away
laugh_loudly
laugh_off
laugh_softly
launch
launder
lave
lavish
lay
layer
lay_aside
lay_away
lay_claim
lay_down
lay_eyes_on
lay_hands_on
lay_in
lay_into
lay_off
lay_on_the_line
lay_out
lay_over
lay_to_rest
lay_up
lay_waste_to
laze
leach
lead
lead_astray
lead_by_the_nose
lead_off
lead_on
lead_up
leaf
league
league_together
leak
leak_out
lean
lean_against
lean_back
lean_on
leap
leapfrog
leap_out
learn
lease
leash
leather
leave
leaven
leave_alone
leave_behind
leave_no_stone_unturned
leave_off
leave_office
leave_out
lech_after
lecture
leech
leech_onto
leer
legalise
legalize
legislate
legitimate
legitimatise
legitimatize
legitimise
legitimize
leg_it
lend
lend_oneself
lengthen
lenify
lessen
let
letter
letter_bomb
let_down
let_drive
let_fly
let_go
let_go_of
let_in
let_it_go
let_loose
let_off
let_on
let_out
let_the_cat_out_of_the_bag
let_up
levant
level
level_off
lever
leverage
levitate
levy
lexicalise
lexicalize
liaise
libel
liberalise
liberalize
liberate
librate
licence
license
lick
lie
lie_about
lie_around
lie_awake
lie_dormant
lie_down
lie_in
lie_in_wait
lie_low
lie_with
lifehack
lift
lift_off
lift_out
lift_up
ligate
light
lighten
lighten_up
lighter
light_up
light_upon
lignify
like
liken
lilt
limber
limber_up
lime
limit
limn
limp
line
linearise
linearize
line_one's_pockets
line_up
linger
linger_over
link
link_up
lionise
lionize
lip-read
lip-sync
lip-synch
lipread
lipstick
lip_off
liquefy
liquidate
liquidise
liquidize
liquify
lisp
list
listen
listen_in
literalise
literalize
lithograph
litigate
litter
live
liven
liven_up
live_down
live_in
live_it_up
live_on
live_out
live_over
live_together
live_up_to
live_with
load
load_down
load_up
loaf
loan
loathe
lob
lobby
localise
localize
locate
lock
lock_away
lock_in
lock_out
lock_up
locomote
lodge
lodge_in
loft
log
log-in
logroll
log_in
log_off
log_on
log_out
log_up
log_z's
loiter
loll
lollop
lollygag
loll_around
long
look
look_across
look_after
look_around
look_at
look_away
look_back
look_backward
look_down_on
look_for
look_forward
look_into
look_like
look_on
look_out
look_out_on
look_out_over
look_sharp
look_to
look_up
look_upon
look_up_to
loom
loop
loose
loosen
loosen_up
loose_off
loot
lop
lope
lop_off
lord
lord_it_over
lose
lose_it
lose_one's_temper
lose_sight_of
lose_track
lose_weight
lot
louden
lounge
lounge_about
lounge_around
lour
louse_up
love
low
lowball
lower
lower_oneself
lube
lubricate
luck_into
luck_it
luck_out
luck_through
lucubrate
luff
lug
luge
lull
lumber
luminesce
lump
lunch
lunge
lurch
lure
lurk
lust
lustrate
lust_after
luxate
luxuriate
lynch
lyophilise
lyophilize
lyric
lysogenize
macadamise
macadamize
macerate
machicolate
machinate
machine
machine-wash
machine_gun
machine_wash
macrame
maculate
madden
madder
madrigal
magnetise
magnetize
magnify
mail
mail_out
maim
mainline
maintain
major
make
make_as_if
make_a_clean_breast_of
make_a_face
make_a_motion
make_a_point
make_a_stink
make_believe
make_bold
make_clean
make_do
make_for
make_full
make_fun
make_good
make_grow
make_happy
make_hay
make_headway
make_it
make_love
make_merry
make_noise
make_no_bones_about
make_off
make_out
make_over
make_pass
make_peace
make_pure
make_relaxed
make_sense
make_sure
make_unnecessary
make_up
make_up_one's_mind
make_vibrant_sounds
make_water
make_way
make_whoopie
maledict
malfunction
malign
malinger
malnourish
malt
maltreat
malversate
mambo
man
manacle
manage
mandate
manducate
maneuver
mangle
manhandle
manicure
manifest
manifold
manipulate
manoeuver
manoeuvre
mantle
manufacture
manumit
manure
map
mapquest
map_out
mar
maraud
marble
marbleise
marbleize
marcel
march
march_on
march_out
marginalise
marginalize
marinade
marinate
mark
market
mark_down
mark_off
mark_out
mark_up
maroon
marry
marshal
martyr
martyrise
martyrize
marvel
masculinise
masculinize
mash
mask
masquerade
mass
mass-produce
massacre
massage
master
mastermind
masticate
masturbate
mat
match
mate
materialise
materialize
matriculate
matt-up
matte
matter
matter_to
matte_up
maturate
mature
mat_up
maul
maunder
maximise
maximize
max_out
mean
meander
measure
measure_out
measure_up
mechanise
mechanize
meddle
mediate
medicate
medicine
meditate
meet
meet_up_with
melanise
melanize
meld
meliorate
mellow
mellow_out
melodise
melodize
melt
melt_down
melt_off
memorialise
memorialize
memorise
memorize
menace
mend
menstruate
mensurate
mention
mentor
meow
mercerise
mercerize
merchandise
merge
merit
mesh
mesmerise
mesmerize
mess
message
mess_about
mess_around
mess_up
metabolise
metabolize
metal
metalize
metallize
metamorphose
metastasise
metastasize
meter
mete_out
metricate
metricise
metricize
metrify
mew
mewl
miaou
miaow
micro-cook
microcopy
microfilm
microwave
micturate
middle
miff
migrate
mildew
militarise
militarize
militate
milk
mill
mill_about
mill_around
mime
mimeo
mimeograph
mimic
mince
mind
mine
mineralize
mingle
miniate
miniaturise
miniaturize
minify
minimise
minimize
minister
minstrel
mint
mire
mirror
misaddress
misadvise
misalign
misally
misapply
misapprehend
misappropriate
misbehave
misbelieve
miscalculate
miscall
miscarry
miscast
miscegenate
misconceive
misconduct
misconstrue
miscount
miscreate
misdate
misdeal
misdeliver
misdemean
misdirect
misdo
misestimate
misfire
misfunction
misgauge
misgive
misgovern
misguide
mishandle
misidentify
misinform
misinterpret
misjudge
mislay
mislead
mismanage
mismarry
mismatch
mismate
misname
misperceive
misplace
misplay
misprint
mispronounce
misquote
misread
misremember
misrepresent
miss
misspeak
misspell
misspend
misstate
mist
mistake
mistime
mistranslate
mistreat
mistrust
mist_over
misunderstand
misuse
miter
mitigate
mix
mix_in
mix_up
mizzle
moan
mob
mobilise
mobilize
mock
mock_up
model
moderate
modernise
modernize
modify
modulate
moil
moisten
moisturise
moisturize
mold
molder
molest
mollify
mollycoddle
molt
monetise
monetize
monger
mongrelise
mongrelize
monish
monitor
monkey
monkey_around
monologuise
monologuize
monopolise
monopolize
monumentalise
monumentalize
moo
mooch
moon
moonlight
moonshine
moon_about
moon_around
moon_on
moor
moot
mop
mope
mope_around
mop_up
moralise
moralize
morph
mortar
mortgage
mortice
mortify
mortise
mosey
mosh
mothball
mother
mothproof
motion
motivate
motley
motor
motorbike
motorboat
motorcycle
motorise
motorize
mottle
mould
moulder
moult
mound
mound_over
mount
mountaineer
mount_up
mourn
mouse
mousse
mouth
mouth_off
move
move_around
move_back
move_back_and_forth
move_in
move_into
move_involuntarily
move_in_on
move_on
move_out
move_over
move_reflexively
move_through
move_up
mow
mow_down
muck
muckrake
muck_about
muck_around
muck_up
mud
mud-wrestle
muddle
muddy
muddy_up
mudwrestle
muff
muffle
mug
mug_up
mulch
mulct
mull
mull_over
multiply
mumble
mummify
munch
munition
murder
murk
murmur
muscle
muscle_into
muse
mush
mushroom
muss
mussitate
muster
muster_in
muster_out
muster_up
mutate
mute
mutilate
mutiny
mutter
muzzle
mystify
mythicise
mythicize
mythologise
mythologize
nab
nag
nail
nail_down
name
namedrop
nap
narcotise
narcotize
nark
narrate
narrow
narrow_down
nasale
nasalise
nasalize
nationalise
nationalize
natter
naturalise
naturalize
nauseate
navigate
nazify
near
neaten
necessitate
neck
necrose
need
needle
negate
negative
neglect
negociate
negotiate
neigh
neighbor
neighbour
nerve
nest
nestle
net
netmail
nett
nettle
network
net_fish
neuter
neutralise
neutralize
nibble
nick
nickel
nickel-and-dime
nicker
nickname
nictate
nictitate
niggle
nigrify
nip
nip_off
nitpick
nitrate
nitrify
nitrogenise
nitrogenize
nix
nobble
nock
nod
nod_off
noise
nol.pros.
nolle_pros
nolle_prosequi
nominate
nonplus
noose
normalise
normalize
nose
nosedive
nose_out
nosh
notarise
notarize
notate
notch
note
notice
notify
nourish
novate
novelise
novelize
nucleate
nudge
nuke
nullify
numb
number
numerate
nurse
nurture
nut
nutate
nutrify
nuzzle
o.d.
o.k.
obey
obfuscate
object
objectify
objurgate
obligate
oblige
obliterate
obnubilate
obscure
observe
obsess
obsolesce
obstinate
obstipate
obstruct
obtain
obtrude
obtrude_upon
obtund
obturate
obviate
occasion
occidentalise
occidentalize
occlude
occult
occupy
occur
odorize
odourise
off
offend
offer
offer_up
officer
officialise
officialize
officiate
offload
offsaddle
offset
ogle
oil
oink
okay
omen
omit
one-step
ooh
ooze
ooze_out
ooze_through
opacify
opalesce
opalise
opalize
open
open_fire
open_up
operate
operate_on
opine
oppose
oppress
oppugn
opsonize
opt
optimise
optimize
opt_out
orate
orb
orbit
orchestrate
ordain
order
ordinate
organise
organize
orient
orientalise
orientalize
orientate
originate
originate_in
ornament
orphan
oscillate
osculate
ossify
ostentate
ostracise
ostracize
oust
out
out-herod
outbalance
outbid
outbrave
outcall
outclass
outcrop
outcry
outdistance
outdo
outdraw
outface
outfight
outfit
outflank
outfox
outgeneral
outgo
outgrow
outguess
outlast
outlaw
outline
outlive
outmaneuver
outmanoeuvre
outmarch
outmatch
outmode
outnumber
outpace
outperform
outplay
outpoint
output
outrage
outrange
outrank
outride
outrival
outroar
outrun
outsail
outscore
outsell
outshine
outshout
outsmart
outsource
outspan
outstare
outstay
outstrip
outvie
outvote
outwear
outweigh
outwit
out_in
ovenbake
oven_broil
over-correct
over-refine
overachieve
overact
overarch
overawe
overbalance
overbear
overbid
overboil
overburden
overcapitalise
overcapitalize
overcast
overcharge
overclothe
overcloud
overcome
overcompensate
overcook
overcrop
overcrowd
overcultivate
overdo
overdose
overdramatise
overdramatize
overdraw
overdress
overdrive
overeat
overemphasise
overemphasize
overestimate
overexert
overexert_oneself
overexploit
overexpose
overextend
overfatigue
overfeed
overfill
overflow
overfly
overgeneralise
overgeneralize
overgorge
overgrow
overhang
overhaul
overhear
overheat
overindulge
overjoy
overlap
overlay
overleap
overlie
overload
overlook
overmaster
overpay
overplay
overpopulate
overpower
overpraise
overprice
overprint
overproduce
overprotect
overrate
overreach
overreact
overrefine
override
overrule
overrun
oversee
oversew
overshadow
overshoot
oversimplify
oversleep
overspecialise
overspecialize
overspend
overspread
overstate
overstay
overstep
overstock
overstrain
overstress
overstretch
overstuff
oversupply
overtake
overtax
overthrow
overtire
overtop
overtrump
overturn
overuse
overvalue
overweary
overwhelm
overwinter
overwork
overwrite
ovulate
owe
own
own_up
oxidate
oxidise
oxidize
oxygenate
oxygenise
oxygenize
oyster
ozonise
ozonize
pace
pacify
pack
package
pack_on
pack_together
pad
paddle
padlock
paganise
paganize
page
paginate
pain
paint
paint_a_picture
paint_the_lily
pair
pair_off
pal
palatalise
palatalize
palaver
pale
palisade
pall
palliate
palm
palm_off
palpate
palpebrate
palpitate
palsy
palter
pal_up
pamper
pan
pan-broil
pan-fry
pander
panel
panhandle
panic
pant
pant-hoot
pantomime
pan_off
pan_out
pan_roast
paper
par
parachute
parade
paragraph
parallel
parallel-park
parallelize
paralyse
paralyze
paraphrase
parboil
parcel
parcel_out
parch
pardon
pare
parent
pare_down
parget
park
parlay
parley
parody
parole
parrot
parry
parse
part
partake
partake_in
parti-color
participate
particularise
particularize
partition
partition_off
partner
partner_off
party
part_with
pass
pass_across
pass_along
pass_around
pass_away
pass_by
pass_judgment
pass_off
pass_on
pass_out
pass_over
pass_through
pass_up
pass_water
pass_with_flying_colors
paste
pasteurise
pasteurize
pasture
pat
patch
patch_up
patent
patinate
patinise
patinize
patrol
patronage
patronise
patronize
patter
pattern
pattern-bomb
pauperise
pauperize
pause
pave
paw
pawn
pay
pay_back
pay_cash
pay_for
pay_heed
pay_off
pay_out
pay_up
peach
peak
peal
pearl
peck
peck_at
peculate
pedal
peddle
pedicure
pee
pee-pee
peek
peel
peel_off
peep
peer
peer_review
peeve
peg
peg_away
peg_down
pelt
pelt_along
pen
penalise
penalize
pencil
penetrate
penny-pinch
pension
pension_off
pen_up
people
pepper
peptise
peptize
pep_up
perambulate
perceive
perch
percolate
percuss
peregrinate
perennate
perfect
perforate
perform
perfume
perfuse
peril
perish
perjure
perk
perk_up
perm
permeate
permit
permute
perorate
peroxide
perpetrate
perpetuate
perplex
persecute
perseverate
persevere
persist
persist_in
personalise
personalize
personate
personify
perspire
persuade
pertain
perturb
peruse
pervade
pervaporate
pervert
pester
pestle
pet
peter_out
petition
petrify
pettifog
phase
phase_in
phase_out
philander
philosophise
philosophize
phlebotomise
phlebotomize
phonate
phone
phosphoresce
photocopy
photograph
photosensitise
photosensitize
photostat
phrase
pick
picket
pickle
pick_apart
pick_at
pick_off
pick_out
pick_over
pick_up
pick_up_the_gauntlet
picnic
picture
piddle
piddle_away
piece
piece-dye
pierce
piffle
pig
pigeonhole
piggyback
pigment
pig_it
pig_out
pile
pile_up
pilfer
pillage
pillory
pillow
pilot
pimp
pin
pinch
pine
pine_away
ping
pinion
pink
pinkify
pinnacle
pinpoint
pin_down
pin_up
pioneer
pip
pipe
pipe-clay
pipe_down
pipe_in
pipe_up
pip_out
pique
pirate
pirouette
piss
pistol-whip
pit
pitch
pitchfork
pitch_in
pitch_into
pith
pitter-patter
pity
pivot
placard
placate
place
place-kick
place_down
place_upright
plagiarise
plagiarize
plague
plain
plait
plan
plane
plank
plank_down
plank_over
plant
plash
plaster
plaster_over
plasticise
plasticize
plastinate
plat
plate
platinize
platitudinize
play
playact
play_along
play_around
play_a_joke_on
play_a_trick_on
play_back
play_down
play_false
play_hooky
play_it_by_ear
play_off
play_out
play_possum
play_tricks
play_up
plea-bargain
pleach
plead
please
pleat
pledge
plicate
plight
plod
plonk
plonk_down
plop
plot
plough
plough_on
plow
plow_ahead
pluck
pluck_at
plug
plug_away
plug_in
plug_into
plumb
plume
plummet
plump
plump_down
plump_for
plump_in
plump_out
plump_up
plunder
plunge
plunk
plunk_down
plunk_for
pluralise
pluralize
ply
poach
pock
pocket
pockmark
pod
podcast
poetise
poetize
point
point_jam
point_out
point_the_way
point_up
poise
poison
poke
poke_at
poke_fun
poke_into
poke_out
polarise
polarize
pole
poleax
poleaxe
polemicise
polemicize
polemise
polemize
police
polish
polish_off
polish_up
politicise
politicize
politick
polka
poll
pollard
pollenate
pollinate
pollute
polychrome
polychromise
polychromize
polymerise
polymerize
pomade
pommel
pompadour
ponder
poniard
pontificate
pony_up
pooch
pooch_out
pooh-pooh
pool
poop_out
pop
popularise
popularize
populate
pop_in
pop_off
pop_out
pop_the_question
pop_up
porcelainize
pore
port
portend
porter
portion
portion_out
portray
pose
posit
position
possess
post
postdate
postmark
postpone
postpose
postulate
posture
pot
potentiate
pother
potter
potter_around
pouch
poultice
pounce
pound
pound_off
pound_up
pour
pour_cold_water_on
pour_down
pour_forth
pour_out
pout
powder
powderise
powderize
power
power-dive
powerwash
powwow
practice
practice_bundling
practise
praise
prance
prang
prang_up
prank
prate
prattle
prawn
pray
preach
preachify
preamble
prearrange
preassemble
precede
precess
precipitate
precis
preclude
preconceive
precondition
precook
predate
predecease
predestinate
predestine
predetermine
predicate
predict
predigest
predispose
predominate
preempt
preen
preexist
prefabricate
preface
prefer
prefigure
prefix
preform
preheat
prehend
preisolate
prejudge
prejudice
prelude
premeditate
premier
premiere
premise
premiss
preoccupy
preordain
prepare
prepare_for
prepay
preponderate
prepose
prepossess
prerecord
presage
prescribe
present
preserve
preside
press
pressure
pressure-cook
pressure-wash
pressurise
pressurize
press_down
press_down_on
press_home
press_on
press_out
presume
presuppose
pretend
pretermit
prettify
pretty_up
prevail
prevaricate
prevent
preview
previse
prey
price
prick
prickle
prick_up
pride
pride_oneself
prim
prime
primp
prim_out
prim_up
prink
print
print_over
prioritise
prioritize
prise
privatise
privatize
privilege
prize
prizefight
probate
probe
proceed
process
proclaim
procrastinate
procreate
proctor
procure
prod
produce
profane
profess
professionalise
professionalize
proffer
profile
profit
profiteer
prognosticate
program
programme
progress
progress_to
prohibit
project
prolapse
proliferate
prologise
prologize
prologuize
prolong
promenade
promise
promote
prompt
promulgate
pronate
pronk
pronounce
proof
proofread
prop
propagandise
propagandize
propagate
propel
prophesy
propitiate
proportion
propose
proposition
propound
prop_up
prorate
prorogue
proscribe
prosecute
proselytise
proselytize
prospect
prosper
prostitute
prostrate
protect
protest
protract
protrude
protuberate
prove
prove_oneself
provide
provision
provoke
prowl
prune
pry
psalm
psychoanalyse
psychoanalyze
psych_up
ptyalise
ptyalize
pub-crawl
publicise
publicize
publish
pucker
puddle
puff
puff_out
puff_up
puke
pule
pull
pullulate
pullulate_with
pull_ahead
pull_along
pull_at
pull_away
pull_a_face
pull_a_fast_one_on
pull_back
pull_down
pull_in
pull_in_one's_horns
pull_off
pull_one's_weight
pull_out
pull_out_all_the_stops
pull_over
pull_round
pull_someone's_leg
pull_strings
pull_the_leg_of
pull_the_plug
pull_the_wool_over_someone's_eyes
pull_through
pull_together
pull_up
pull_up_short
pull_up_stakes
pull_wires
pulp
pulsate
pulse
pulverise
pulverize
pumice
pummel
pump
pun
punch
punch_in
punch_out
punctuate
puncture
punish
punt
pup
pupate
purchase
puree
purge
purify
purl
purloin
purl_stitch
purple
purport
purpose
purpurate
purr
purse
pursue
purvey
push
push_around
push_aside
push_away
push_back
push_down
push_forward
push_on
push_out
push_through
push_up
pussyfoot
put
putrefy
putt
putter
putter_around
putty
put_across
put_aside
put_away
put_back
put_behind_bars
put_down
put_forward
put_in
put_off
put_on
put_one_across
put_one_over
put_on_airs
put_on_the_line
put_out
put_out_feelers
put_over
put_right
put_through
put_together
put_to_death
put_to_sleep
put_to_work
put_under
put_up
puzzle
puzzle_out
puzzle_over
pyramid
quack
quadruple
quadruplicate
quaff
quail
quail_at
quake
qualify
quantify
quantise
quantize
quarantine
quarrel
quarry
quarter
quarterback
quash
quaver
queen
queen_it_over
queer
quell
quench
query
quest
question
quest_after
quest_for
quetch
queue
queue_up
quibble
quick-freeze
quicken
quickstep
quiesce
quiet
quieten
quiet_down
quilt
quintuple
quip
quirk
quit
quiver
quiz
quote
rabbet
rabbit
rabbit_on
race
rachet_up
rack
racket
racketeer
rack_up
raddle
radiate
radicalize
radio
radiolocate
raffle
raffle_off
raft
rafter
rag
rage
raid
rail
railroad
rail_in
rail_off
raiment
rain
rain_buckets
rain_cats_and_dogs
rain_down
rain_out
raise
raise_a_stink
raise_hell
raise_the_roof
raise_up
rake
rake_in
rake_off
rake_up
rally
ram
ramble
ramble_on
ramify
ramp
rampage
ramp_up
ram_down
ram_home
ranch
randomise
randomize
range
range_in
rank
rankle
ransack
ransom
rant
rap
rape
rappel
rarefy
rarify
rase
rasp
rasterize
rat
ratchet
ratchet_down
rate
ratify
ratiocinate
ration
rationalise
rationalise_away
rationalize
rationalize_away
ration_out
rattle
rattle_down
rattle_off
rattle_on
ravage
rave
ravel
ravel_out
raven
ravish
ray
raze
razor
razz
re-address
re-afforest
re-argue
re-arm
re-assume
re-create
re-emerge
re-emphasise
re-emphasize
re-enter
re-equip
re-examine
re-explain
re-explore
re-incorporate
re-introduce
re-start
reabsorb
reach
reach_into
reach_one's_nostrils
reach_out
reacquaint
react
reactivate
read
readapt
readjust
readmit
ready
read_between_the_lines
reaffirm
realign
realine
realise
realize
reallocate
reallot
ream
reanimate
reap
reappear
reapportion
reappraise
rear
rear-end
rearm
rearrange
rear_back
reason
reason_out
reassail
reassemble
reassert
reassess
reassign
reassure
reattribute
reave
reawaken
rebate
rebel
rebind
reboot
rebound
rebroadcast
rebuff
rebuild
rebuke
rebury
rebut
recalcitrate
recalculate
recall
recant
recap
recapitulate
recapture
recast
recede
receipt
receive
recess
recharge
recidivate
reciprocate
recite
reckon
reclaim
reclassify
recline
recode
recognise
recognize
recoil
recollect
recombine
recommence
recommend
recommit
recompense
reconcile
recondition
reconfirm
reconnoiter
reconnoitre
reconquer
reconsecrate
reconsider
reconstitute
reconstruct
reconvene
reconvert
reconvict
recopy
record
recount
recoup
recover
recreate
recriminate
recrudesce
recruit
rectify
recumb
recuperate
recur
recurve
recuse
recycle
red-eye
red-ink
redact
redden
rede
redecorate
rededicate
redeem
redefine
redeploy
redeposit
redesign
redetermine
redevelop
redirect
rediscover
redispose
redistribute
redline
redo
redouble
redound
redress
reduce
reduplicate
reecho
reef
reek
reel
reelect
reel_off
reenact
reenforce
reestablish
reevaluate
reeve
reexamine
reface
refashion
refer
referee
reference
refill
refinance
refine
refinish
refit
reflate
reflect
reflectorise
reflectorize
refloat
refocus
reforest
reforge
reform
reformulate
refract
refracture
refrain
refresh
refreshen
refrigerate
refuel
refund
refurbish
refurnish
refuse
refute
regain
regale
regard
regard_as
regenerate
regiment
register
regorge
regress
regret
regroup
regrow
regularise
regularize
regulate
regurgitate
rehabilitate
reharmonise
reharmonize
rehash
rehear
rehearse
reheat
reheel
rehouse
reify
reign
reignite
reimburse
reimpose
rein
reincarnate
reinforce
reinstall
reinstate
reinsure
reintegrate
reinterpret
reintroduce
reinvent
reinvigorate
rein_in
reissue
reiterate
reject
rejig
rejoice
rejoin
rejuvenate
rekindle
relace
relapse
relate
relativise
relativize
relax
relay
relearn
release
relegate
relent
relieve
relieve_oneself
reline
relinquish
relish
relive
reload
relocate
rely
relyric
rely_on
rely_upon
remain
remainder
remain_down
remain_firm
remake
remand
remark
remarry
remediate
remedy
remember
remember_oneself
remilitarise
remilitarize
remind
reminisce
remit
remodel
remold
remonstrate
remould
remount
remove
remunerate
rename
rend
render
render-set
rendezvous
renegade
renege
renege_on
renegociate
renegotiate
renegue_on
renew
renormalise
renormalize
renounce
renovate
rent
rent_out
reopen
reorder
reorganise
reorganize
reorient
reorientate
repaint
repair
repatriate
repay
repeal
repeat
repel
repent
repercuss
rephrase
repine
replace
replant
replay
replenish
replete
replicate
reply
repoint
report
report_out
repose
repose_on
reposit
reposition
repossess
repot
reprehend
represent
repress
reprieve
reprimand
reprint
reprise
reprize
reproach
reprobate
reprocess
reproduce
reproof
reprove
republish
repudiate
repugn
repulse
repurchase
repute
request
require
requisition
requite
reread
rerun
rescale
reschedule
rescind
rescue
reseal
research
reseat
resect
reseed
resell
resemble
resent
reserve
reset
resettle
resew
reshape
reship
reshoot
reshuffle
reside
resift
resign
resile
resinate
resist
resize
resmudge
resole
resolve
resonate
resorb
resort
resound
respect
respire
respite
resplend
respond
rest
restart
restate
restitute
restock
restore
restrain
restrengthen
restrict
restructure
rest_on
resublime
resubmit
result
resume
resurface
resurge
resurrect
resuscitate
resuspend
ret
retail
retain
retake
retaliate
retard
retch
retell
rethink
retick
reticulate
retie
retire
retool
retort
retouch
retrace
retract
retrain
retranslate
retransmit
retread
retreat
retrench
retrieve
retrofit
retroflex
retrograde
retrogress
retrospect
retrovert
retry
return
reunify
reunite
reuse
rev
revalue
revamp
reveal
revel
revenge
reverberate
revere
reverence
reverse
revert
revet
review
revile
revise
revisit
revitalise
revitalize
revive
revivify
revoke
revolt
revolutionise
revolutionize
revolve
revolve_about
revolve_around
rev_up
reward
rewire
reword
rework
rewrite
rhapsodise
rhapsodize
rhumba
rhyme
rib
rice
rick
ricochet
rid
riddle
ride
ride_away
ride_herd
ride_horseback
ride_off
ride_out
ride_roughshod
ride_the_bench
ridge
ridicule
rid_of
riff
riffle
rifle
rig
right
rigidify
rig_out
rig_up
rile
rim
rime
ring
ring_out
ring_up
rinse
rinse_off
riot
rip
ripen
riposte
ripple
rip_off
rip_out
rip_up
rise
rise_up
risk
ritualise
ritualize
rival
rive
rivet
roach
roam
roar
roar_off
roast
rob
robe
rock
rocket
roil
roister
roleplay
roll
rollerblade
roller_skate
rollick
roll_around
roll_down
roll_in
roll_in_the_hay
roll_off
roll_out
roll_over
roll_up
romance
romanise
romanize
romanticise
romanticize
romp
roneo
roof
rook
room
roost
root
rootle
root_for
root_on
root_out
rope
rope_down
rope_in
rope_off
rope_up
rosin
rot
rotate
rouge
rough
rough-dry
rough-hew
rough-house
rough-sand
roughcast
roughen
roughhouse
rough_in
rough_out
rough_up
round
round_down
round_off
round_out
round_up
rouse
rout
route
rout_out
rout_up
rove
row
rub
rubber
rubberise
rubberize
rubberneck
rubberstamp
rubbish
rubify
rubric
rubricate
rub_along
rub_down
rub_off
rub_out
ruck
ruckle
ruck_up
ruddle
rue
ruff
ruffle
ruffle_up
ruggedise
ruggedize
ruin
rule
rule_in
rule_out
rumba
rumble
ruminate
rummage
rumor
rumour
rumple
rumpus
run
run_across
run_afoul
run_aground
run_along
run_around
run_away
run_a_risk
run_bases
run_by
run_down
run_dry
run_for
run_into
run_low
run_off
run_on
run_out
run_over
run_roughshod
run_short
run_through
run_up
rupture
rush
rush_along
rush_away
rush_off
rush_out
rust
rusticate
rustle
rut
saber
sabotage
sabre
saccharify
sack
sack_out
sack_up
sacrifice
sadden
saddle
safeguard
sag
sag_down
sail
sailplane
sail_through
saint
salaam
salinate
salivate
sallow
sally_forth
sally_out
salt
saltate
salt_away
salute
salvage
salve
samba
sample
sanctify
sanction
sand
sandbag
sandblast
sandpaper
sandwich
sand_cast
sanitate
sanitise
sanitize
sap
saponify
sashay
sass
sate
satellite
satiate
satirise
satirize
satisfice
satisfise
satisfy
saturate
sauce
saunter
saute
savage
save
save_up
savor
savour
savvy
saw
saw_logs
saw_wood
say
say_farewell
scab
scaffold
scald
scale
scale_down
scale_up
scallop
scalp
scam
scamp
scamper
scan
scandalise
scandalize
scant
scar
scare
scare_away
scare_off
scarf
scarf_out
scarify
scarper
scat
scatter
scavenge
scend
scent
scent_out
schedule
schematise
schematize
scheme
schlep
schmoose
schmooze
schnorr
school
schuss
scintillate
scissor
sclaff
scoff
scold
scollop
scoop
scoop_out
scoop_up
scoot
scorch
score
score_out
scorn
scotch
scotch_tape
scour
scourge
scout
scowl
scrabble
scrag
scram
scramble
scranch
scrap
scrape
scrape_along
scrape_by
scrape_up
scratch
scratch_along
scratch_off
scratch_out
scratch_up
scraunch
scrawl
screak
scream
screech
screen
screen_off
screen_out
screw
screw_up
scribble
scribe
scrimmage
scrimp
scrimshank
script
scroll
scrounge
scrub
scrub_up
scrunch
scrunch_up
scruple
scrutinise
scrutinize
scry
scud
scuff
scuffle
scull
sculpt
sculpture
scum
scupper
scurry
scuttle
scythe
seal
seal_in
seal_off
seam
seaplane
sear
search
season
seat
secede
secern
secernate
seclude
second
second-guess
secrete
section
sectionalise
sectionalize
secularise
secularize
secure
sedate
sediment
seduce
see
seed
seek
seek_out
seel
seem
seep
seesaw
seethe
see_double
see_eye_to_eye
see_red
see_the_light
see_through
see_to_it
segment
segregate
segue
seine
seize
seize_on
seize_with_teeth
select
self-destroy
self-destruct
sell
sellotape
sell_off
sell_out
sell_short
sell_up
semaphore
semi-automatise
semi-automatize
send
send_around
send_away
send_a_message
send_back
send_down
send_for
send_in
send_off
send_on
send_out
send_packing
send_word
senesce
sense
sensibilise
sensibilize
sensify
sensitise
sensitize
sensualise
sensualize
sentence
sentimentalise
sentimentalize
sentimentise
sentimentize
separate
separate_off
separate_out
sequence
sequester
sequestrate
serenade
serialise
serialize
sermonise
sermonize
serrate
serve
serve_up
serve_well
service
set
settle
settle_down
settle_on
set_ablaze
set_about
set_afire
set_aflame
set_ahead
set_apart
set_ashore
set_aside
set_back
set_down
set_forth
set_free
set_in
set_in_motion
set_off
set_on
set_on_fire
set_out
set_to_music
set_up
set_upon
sever
severalise
severalize
sew
sew_together
sex
sexualise
sexualize
sex_up
shack
shackle
shack_up
shade
shade_off
shadow
shadowbox
shaft
shag
shake
shake_hands
shake_off
shake_up
shallow
sham
shamanise
shamanize
shamble
shame
shampoo
shanghai
shank
shape
shape_up
share
shark
sharpen
sharpshoot
shatter
shave
she-bop
shear
sheathe
shed
shed_blood
shed_light_on
sheer
sheet
shell
shellac
shellack
shell_out
shell_stitch
shelter
shelve
shepherd
shew
shield
shift
shill
shillyshally
shimmer
shimmy
shin
shine
shine_at
shine_up
shingle
shinny
ship
shipwreck
shirk
shirr
shirt
shit
shiver
shlep
shmoose
shmooze
shnorr
shoal
shock
shoe
shoehorn
shoetree
shoo
shoot
shoot_a_line
shoot_craps
shoot_down
shoot_for
shoot_one's_mouth_off
shoot_the_breeze
shoot_up
shoo_away
shoo_off
shop
shoplift
shop_at
shore
shore_up
short
short-change
short-circuit
shorten
shortlist
shoulder
shoulder_in
shout
shout_down
shout_out
shove
shovel
shovel_in
shove_along
shove_off
show
shower
shower_down
show_off
show_the_door
show_up
shred
shriek
shrill
shrimp
shrine
shrink
shrinkwrap
shrink_back
shrink_from
shrive
shrivel
shrivel_up
shroud
shrug
shrug_off
shuck
shudder
shuffle
shun
shunt
shush
shut
shutter
shuttle
shuttlecock
shut_away
shut_down
shut_in
shut_off
shut_one's_mouth
shut_out
shut_up
shy
shy_away_from
sibilate
sic
sick
sicken
side
side-slip
sideline
sidestep
sideswipe
sidetrack
sidle
sidle_up
sieve
sieve_out
sift
sigh
sight
sight-read
sight-sing
sightread
sightsee
sightsing
sign
signal
signalise
signalize
signify
signpost
sign_away
sign_in
sign_off
sign_on
sign_over
sign_up
silence
silhouette
silkscreen
silt
silt_up
silver
silver-plate
silverplate
simmer
simmer_down
simonise
simonize
simper
simplify
simulate
sin
sing
singe
single
single-foot
single_crochet
single_out
single_stitch
singsong
singularise
singularize
sing_along
sink
sink_in
sinter
sip
siphon
siphon_off
sire
siss
sit
site
situate
sit_around
sit_back
sit_by
sit_down
sit_in
sit_out
sit_tight
sit_up
size
size_up
sizz
sizzle
skank
skate
skateboard
skate_over
skedaddle
sketch
skew
skewer
ski
skid
skim
skimcoat
skimp
skimp_over
skim_off
skim_over
skin
skin-dive
skinny-dip
skin_over
skin_pop
skip
skip-bomb
skipper
skip_over
skip_town
skirl
skirmish
skirt
skitter
skittle
skive
ski_jump
skreak
skreigh
skulk
skunk
sky
skydive
skyjack
skylark
skyrocket
sky_dive
slabber
slack
slacken
slacken_off
slack_off
slack_up
slag
slake
slalom
slam
slam-dunk
slam_dance
slam_on
slander
slang
slant
slap
slap_on
slap_together
slash
slat
slate
slather
slaughter
slave
slaver
slay
sled
sledge
sledgehammer
sleek
sleek_down
sleek_over
sleep
sleepwalk
sleep_around
sleep_in
sleep_late
sleep_off
sleep_out
sleep_over
sleep_together
sleep_with
sleet
sleigh
slenderise
slenderize
sleuth
slew
slice
slice_into
slice_through
slice_up
slick
slick_down
slick_up
slide
slide_by
slide_down
slight
slim
slime
slim_down
sling
slink
slip
slip_away
slip_by
slip_in
slip_off
slip_on
slip_one's_mind
slip_up
slit
slither
sliver
slobber
slobber_over
slog
sloganeer
slop
slope
slosh
slosh_around
slot
slouch
slough
slough_off
slow
slow_down
slow_up
slue
slug
sluice
sluice_down
slum
slumber
slump
slur
slurp
slur_over
slush
slush_around
smack
smart
smarten_up
smash
smash_up
smatter
smear
smell
smell_out
smell_up
smelt
smile
smirch
smirk
smite
smock
smoke
smoke_out
smolder
smooch
smooth
smoothen
smooth_out
smooth_over
smother
smoulder
smudge
smuggle
smut
smutch
snack
snaffle
snafu
snag
snail
snake
snap
snap_at
snap_back
snap_off
snap_up
snare
snarf
snarl
snarl_up
snatch
snatch_up
sneak
sneak_away
sneak_in
sneak_off
sneak_out
sneak_up
sneer
sneeze
snick
snicker
sniff
sniffle
sniff_out
snigger
snip
snipe
snip_off
snitch
snivel
snog
snooker
snoop
snooze
snore
snorkel
snort
snow
snow-blind
snowball
snowboard
snowmobile
snowshoe
snub
snuff
snuffle
snuff_it
snuff_out
snuggle
soak
soak_through
soak_up
soap
soar
soar_up
soar_upwards
sob
sober
sober_up
socialise
socialize
sock
sod
sodomise
sodomize
soft-pedal
soft-soap
soft-solder
soften
soil
sojourn
solace
solarise
solarize
solder
soldier
sole
solemnise
solemnize
solicit
solidify
soliloquise
soliloquize
solmizate
solo
solvate
solve
somersault
somnambulate
sonnet
soot
soothe
sop
sophisticate
sop_up
sorb
sorcerise
sorcerize
sorrow
sort
sort_out
sough
sound
soundproof
sound_off
sound_out
soup
soup_up
sour
source
souse
sovietise
sovietize
sow
sow_in
sow_one's_oats
sow_one's_wild_oats
space
spacewalk
spade
spam
span
spang
spangle
spank
spar
spare
sparge
spark
sparkle
spark_off
spat
spatchcock
spatter
spawn
spay
speak
speak_for
speak_in_tongues
speak_of_the_devil
speak_out
speak_up
spear
spearhead
spear_up
specialise
specialize
speciate
specify
speck
speckle
spectate
speculate
speech-read
speechify
speed
speed_skate
speed_up
spell
spellbind
spell_out
spelunk
spend
spend_a_penny
spew
spew_out
sphacelate
spice
spice_up
spiel
spiel_off
spiff_up
spike
spike_out
spill
spill_out
spill_over
spill_the_beans
spin
spin-dry
spin_around
spin_off
spin_out
spiral
spirit
spiritise
spiritize
spiritualise
spiritualize
spirit_away
spirit_off
spirit_up
spirt
spit
spite
spit_out
spit_up
splash
splash_around
splat
splatter
splay
splice
splint
splinter
split
split_up
splosh
splotch
splurge
splutter
spoil
spondaise
spondaize
sponge
sponge_down
sponge_off
sponge_on
sponge_up
sponsor
spoof
spook
spool
spoon
spoonfeed
sport
sportscast
sporulate
spot
spot-check
spot-weld
spotlight
spotweld
spot_jam
spot_promote
spout
sprain
sprawl
spray
spray-dry
spread
spread-eagle
spreadeagle
spread_out
spread_over
spree
spring
spring-clean
spring_to_mind
spring_up
sprinkle
sprint
spritz
sprout
spruce
spruce_up
spud
spue
spume
spur
spurn
spurt
sputter
spy
squabble
squall
squander
square
square_away
square_dance
square_off
square_up
squash
squat
squawk
squeak
squeak_by
squeak_through
squeal
squeegee
squeeze
squeeze_by
squeeze_for
squeeze_out
squelch
squinch
squint
squire
squirm
squirrel_away
squirt
squish
stab
stabilise
stabilize
stable
stack
stack_away
stack_up
staff
stag
stage
stage_direct
stagger
stagnate
stain
stake
stale
stalemate
stalinise
stalinize
stalk
stall
stammer
stamp
stampede
stamp_down
stamp_out
stanch
stand
standardise
standardize
stand_back
stand_by
stand_fast
stand_firm
stand_for
stand_guard
stand_in
stand_out
stand_pat
stand_sentinel
stand_still
stand_up
stand_watch
staple
star
starboard
starch
stare
stare_down
stargaze
start
startle
start_out
start_up
starve
stash
stash_away
state
station
staunch
stave
stave_in
stave_off
stay
stay_at
stay_away
stay_fresh
stay_in_place
stay_off
stay_on
stay_over
stay_put
stay_together
stay_up
steady
steady_down
steal
steal_away
steam
steam-heat
steamer
steamroll
steamroller
steam_clean
steel
steel_oneself_against
steel_onself_for
steep
steepen
steer
stem
stencil
stenograph
step
step_down
step_forward
step_in
step_on
step_on_it
step_out
step_to_the_fore
step_up
stereotype
sterilise
sterilize
stet
stew
stick
stickle
stick_about
stick_around
stick_by
stick_in
stick_on
stick_out
stick_to
stick_together
stick_up
stick_with
stiffen
stifle
stigmatise
stigmatize
still
still-fish
still-hunt
stimulate
sting
stink
stink_out
stink_up
stint
stipple
stipulate
stir
stir_fry
stir_up
stitch
stock
stock-take
stockade
stockpile
stock_up
stoke
stomach
stomp
stone
stone-wash
stonewall
stonewash
stooge
stool
stoop
stoop_to
stop
stopper
stopple
stop_dead
stop_over
stop_up
store
storm
stow
stow_away
straddle
strafe
straggle
straighten
straighten_out
straighten_up
strain
straiten
strand
strangle
strangulate
strap
stratify
straw
stray
streak
stream
streamline
street-walk
streetwalk
strengthen
stress
stretch
stretch_along
stretch_forth
stretch_out
strew
striate
strickle
stride
stridulate
strike
strike_a_blow
strike_a_chord
strike_a_note
strike_back
strike_down
strike_dumb
strike_hard
strike_home
strike_off
strike_out
strike_up
string
string_along
string_out
string_up
strip
strip-search
stripe
strip_down
strip_mine
strive
stroke
stroll
strong-arm
strop
structure
struggle
strum
strut
stub
stub_out
stucco
stud
study
stuff
stultify
stumble
stump
stun
stunt
stupefy
stutter
style
stylise
stylize
stymie
stymy
sub
subcontract
subdivide
subdue
subedit
subject
subjoin
subjugate
sublease
sublet
sublimate
sublime
subluxate
submarine
submerge
submerse
submit
subordinate
suborn
subpoena
subrogate
subscribe
subscribe_to
subserve
subside
subsidise
subsidize
subsist
substantiate
substitute
subsume
subtend
subtilise
subtilize
subtitle
subtract
suburbanise
suburbanize
subvent
subvention
subvert
subvocalise
subvocalize
succeed
succor
succour
succumb
succuss
suck
suckle
suck_in
suck_out
suck_up
suction
sudate
suds
sue
suffer
suffice
suffix
suffocate
suffuse
sugar
sugarcoat
suggest
suit
sulfate
sulfur
sulfurette
sulk
sully
sulphur
sulphurette
sum
summarise
summarize
summate
summer
summerise
summerize
summit
summon
summons
sum_up
sun
sunbathe
sunburn
sunder
suntan
sup
superannuate
supercede
supercharge
superfetate
superimpose
superinfect
superintend
superordinate
superpose
superscribe
supersede
supervene
supervene_upon
supervise
supinate
supplant
supple
supplement
supplicate
supply
support
suppose
suppress
suppurate
surcharge
surf
surface
surface-mine
surface_mine
surfboard
surfeit
surge
surmise
surmount
surpass
surprise
surrender
surround
surtax
surveil
survey
survive
suspect
suspend
suspire
suss_out
sustain
susurrate
suture
swab
swaddle
swag
swage
swagger
swallow
swallow_up
swamp
swan
swank
swap
swarm
swash
swat
swathe
swatter
sway
swear
swear_in
swear_off
swear_out
sweat
sweat_off
sweep
sweep_away
sweep_off
sweep_over
sweep_through
sweep_under_the_rug
sweep_up
sweet-talk
sweeten
swell
swell_up
swelter
swerve
swig
swill
swill_down
swim
swindle
swing
swinge
swing_about
swing_around
swing_out
swing_over
swipe
swirl
swish
switch
switch-hit
switch_off
switch_on
switch_over
swivel
swob
swoon
swoop
swoop_up
swoosh
swop
swosh
swot
swot_up
syllabicate
syllabify
syllabise
syllabize
syllogise
syllogize
symbolise
symbolize
symmetrise
symmetrize
sympathise
sympathize
sympathize_with
symphonise
symphonize
sync
synchronise
synchronize
syncopate
syncretise
syncretize
syndicate
synthesise
synthesize
syphon
syringe
systematise
systematize
systemise
systemize
table
taboo
tabularise
tabularize
tabulate
tack
tackle
tack_on
tack_together
tag
tag_along
tag_on
tail
tailgate
tailor
tailor-make
taint
take
take_aback
take_account
take_advantage
take_after
take_aim
take_apart
take_arms
take_away
take_a_bow
take_a_breath
take_a_breather
take_a_chance
take_a_crap
take_a_dare
take_a_dive
take_a_firm_stand
take_a_hit
take_a_hop
take_a_joke
take_a_leak
take_a_look
take_a_powder
take_a_shit
take_back
take_care
take_chances
take_charge
take_control
take_down
take_effect
take_exception
take_fire
take_five
take_flight
take_for
take_form
take_for_granted
take_heart
take_heed
take_hold
take_hold_of
take_home
take_in
take_into_account
take_in_charge
take_in_vain
take_in_water
take_issue
take_it_easy
take_it_on_the_chin
take_kindly_to
take_leave
take_lying_down
take_note
take_notice
take_off
take_office
take_on
take_one's_lumps
take_orders
take_out
take_over
take_pains
take_part
take_place
take_pride
take_root
take_shape
take_stage
take_stock
take_ten
take_the_air
take_the_bull_by_the_horns
take_the_cake
take_the_count
take_the_field
take_the_fifth
take_the_fifth_amendment
take_the_floor
take_the_road
take_the_stage
take_the_stand
take_the_veil
take_time_by_the_forelock
take_time_off
take_to
take_to_be
take_to_heart
take_to_task
take_to_the_woods
take_turns
take_up
take_up_arms
take_water
talc
talk
talk_about
talk_down
talk_into
talk_of
talk_out_of
talk_over
talk_shop
talk_terms
talk_through_one's_hat
talk_turkey
tally
tame
tamp
tamper
tampon
tamp_down
tan
tangle
tangle_with
tango
tank
tantalise
tantalize
tap
tapdance
tape
taper
taper_off
tape_record
tap_dance
tap_out
tar
tar-and-feather
target
tariff
tarmac
tarnish
tarry
tart_up
task
taste
tat
tattle
tattoo
taunt
tauten
tax
taxi
teach
team
team_up
tear
teargas
tear_apart
tear_away
tear_down
tear_into
tear_off
tear_up
tease
tease_apart
tee
teem
teem_in
teeter
teeter-totter
teetertotter
teethe
teetotal
tee_off
tee_up
telecast
telecommunicate
telefax
telegraph
telepathise
telepathize
telephone
teleport
telescope
televise
telex
tell
tell_apart
tell_off
tell_on
temper
temporise
temporize
tempt
tenant
tend
tender
tenderise
tenderize
tense
tense_up
tent
tenure
tergiversate
term
terminate
terrace
terrasse
terrify
territorialise
territorialize
terrorise
terrorize
tessellate
test
testify
test_drive
test_fly
tether
thank
thatch
thaw
theme
theologise
theologize
theorise
theorize
thermostat
thicken
thieve
thin
think
think_about
think_back
think_of
think_out
think_over
think_the_world_of
think_twice
think_up
thin_out
thirst
thoriate
thrash
thrash_about
thrash_out
thread
threaten
thresh
thresh_about
thrill
thrive
throb
thrombose
throne
throng
throttle
throw
throw_away
throw_a_fit
throw_back
throw_cold_water_on
throw_in
throw_in_the_towel
throw_off
throw_out
throw_out_of_kilter
throw_overboard
throw_together
throw_up
thrum
thrust
thrust_ahead
thrust_out
thud
thumb
thumbtack
thump
thump_out
thunder
thurify
thwack
thwart
tick
ticket
tickle
tickle_pink
ticktack
ticktock
tick_off
tick_over
tide
tide_over
tidy
tidy_up
tie
tie-dye
tie_down
tie_in
tie_up
tighten
tighten_one's_belt
tighten_up
tile
till
tiller
tilt
time
tin
tinct
tincture
ting
tinge
tingle
tink
tinker
tinkle
tinsel
tint
tintinnabulate
tip
tipple
tippytoe
tiptoe
tip_off
tip_over
tire
tire_out
tissue
tithe
titillate
titivate
title
titrate
titter
tittivate
tittle-tattle
tittup
toady
toast
toboggan
toddle
toe
toenail
toe_the_line
tog
toggle
tog_out
tog_up
toil
toilet-train
tolerate
toll
tomahawk
tone
tone_down
tone_up
tongue
tongue-tie
tonsure
tool
tool_around
toot
tootle
top
topdress
tope
topicalize
topple
top_off
top_out
torch
torment
torpedo
torture
toss
toss_away
toss_back
toss_in
toss_off
toss_out
tot
total
totalise
totalize
tote
tote_up
totter
tot_up
touch
touch-type
touch_a_chord
touch_base
touch_down
touch_off
touch_on
touch_up
toughen
tour
tourney
tousle
tout
tow
towel
tower
toy
toy_with
trace
track
track_down
trade
trademark
trade_in
traduce
traffic
trail
train
traipse
tram
trammel
tramp
trample
tramp_down
trance
tranquilize
tranquillise
tranquillize
transact
transaminate
transcend
transcribe
transduce
transect
transfer
transfigure
transfix
transform
transfuse
transgress
transistorise
transistorize
transit
transition
transitivise
transitivize
translate
transliterate
translocate
transmigrate
transmit
transmogrify
transmute
transpirate
transpire
transplant
transport
transpose
transship
transubstantiate
transude
trap
trash
traumatise
traumatize
travail
travel
travel_along
travel_by
travel_purposefully
travel_rapidly
travel_to
traverse
travesty
trawl
tread
treadle
tread_down
tread_on
treasure
treat
treble
tree
trek
trellis
tremble
tremor
trench
trend
trepan
trephine
trespass
triangulate
tribulate
trice
trice_up
trick
trickle
trick_out
trick_up
trifle
trifle_away
trifurcate
trigger
trigger_off
trill
trim
trim_back
trim_down
trip
triple
triple-space
triple-tongue
triplicate
trip_out
trip_the_light_fantastic
trip_the_light_fantastic_toe
trip_up
trisect
triumph
trivialise
trivialize
troat
troll
troop
trot
trot_out
trouble
trouble-shoot
troubleshoot
trouble_oneself
trounce
trowel
truck
truckle
trudge
true
true_up
trump
trumpet
trump_out
trump_up
truncate
trundle
truss
trust
try
try_for
try_on
try_out
tsk
tube
tuck
tucker
tucker_out
tuck_away
tuck_in
tug
tumble
tumble_dry
tumefy
tumesce
tump_over
tune
tune_in
tune_up
tunnel
turf
turf_out
turn
turn_around
turn_away
turn_a_blind_eye
turn_a_loss
turn_a_nice_dime
turn_a_nice_dollar
turn_a_nice_penny
turn_a_profit
turn_a_trick
turn_back
turn_down
turn_in
turn_off
turn_on
turn_one's_stomach
turn_on_a_dime
turn_out
turn_over
turn_tail
turn_the_tables
turn_the_tide
turn_thumbs_down
turn_to
turn_turtle
turn_up
turn_up_the_heat
turn_up_the_pressure
turtle
tusk
tussle
tut
tut-tut
tutor
twaddle
twang
tweak
tweedle
tweet
tweeze
twiddle
twig
twill
twin
twine
twinge
twinkle
twirl
twirp
twist
twist_around
twit
twitch
twitter
two-step
two-time
type
typecast
typeset
typewrite
typify
tyrannise
tyrannize
uglify
ulcerate
ultracentrifuge
ululate
umpire
unarm
unbalance
unbar
unbelt
unbend
unbind
unblock
unbolt
unbosom
unbox
unbrace
unbraid
unbridle
unbuckle
unburden
unbutton
uncase
unchain
unchurch
unclasp
unclip
uncloak
unclog
unclothe
unclutter
uncoil
uncompress
uncork
uncouple
uncover
uncrate
uncross
uncurl
undeceive
underachieve
underact
underbid
undercharge
undercoat
undercut
underdevelop
underdress
underestimate
underexpose
undergird
undergo
undergrow
underlay
underlie
underline
undermine
undernourish
underpay
underperform
underpin
underplay
underprice
underproduce
underquote
underrate
underscore
undersell
undershoot
undersign
underspend
understand
understate
understock
understudy
undertake
undervalue
underwrite
undo
undock
undrape
undress
undulate
unearth
unfasten
unfit
unfold
unfreeze
unfrock
unfurl
unhallow
unhand
unharness
unhinge
unhitch
unhook
unhorse
unicycle
uniform
uniformise
uniformize
unify
unionise
unionize
unite
unitise
unitize
universalise
universalize
unknot
unlace
unlade
unlash
unlax
unlearn
unleash
unlive
unload
unlock
unloose
unloosen
unmake
unman
unmask
unmuzzle
unnerve
unpack
unpick
unpin
unplug
unravel
unreel
unroll
unsaddle
unsanctify
unsay
unscramble
unscrew
unseal
unseat
unsettle
unsex
unsheathe
unsnarl
unsolder
unspell
unstaple
unstrain
unstrap
unstring
unstuff
unsubstantialise
unsubstantialize
untangle
unteach
unthaw
untie
untune
untwine
untwist
unveil
unweave
unwind
unwire
unwrap
unyoke
unzip
up
upbraid
upchuck
update
upend
upgrade
upheave
uphold
upholster
uplift
upload
upraise
uprise
uproot
upset
upstage
urbanise
urbanize
urge
urge_on
urinate
urticate
use
use_up
usher
usher_in
usher_out
usurp
utilise
utilize
utter
vacate
vacation
vaccinate
vacillate
vacuum
vacuum-clean
vagabond
valet
validate
valuate
value
vamoose
vamp
vamp_up
vandalise
vandalize
vanish
vanquish
vaporise
vaporize
variegate
varnish
vary
vascularise
vascularize
vasectomise
vasectomize
vaticinate
vault
vaunt
veer
vegetate
vege_out
veil
vein
velcro
vellicate
vend
veneer
venerate
venesect
vent
ventilate
venture
verbalise
verbalize
verbify
verdigris
verge
verify
vermiculate
vermilion
verse
versify
vesicate
vesiculate
vest
vesture
vet
veto
vex
vibrate
victimise
victimize
victual
videotape
vie
view
view_as
vilify
vilipend
vindicate
vinify
violate
virilise
virilize
visa
visit
visualise
visualize
vitalise
vitalize
vitaminise
vitaminize
vitiate
vitrify
vitriol
vituperate
vivify
vivisect
vocalise
vocalize
vociferate
voice
void
volatilise
volatilize
volley
volunteer
vomit
vomit_up
voodoo
vote
vote_down
vote_in
vote_out
vouch
vouchsafe
vow
vowelise
vowelize
voyage
vroom
vulcanise
vulcanize
vulgarise
vulgarize
wad
waddle
wade
waffle
waft
wag
wage
wager
waggle
wail
wait
waitress
wait_on
waive
wake
waken
wake_up
walk
walk_about
walk_around
walk_away
walk_in
walk_off
walk_on_air
walk_out
walk_out_of
walk_over
walk_through
wall
wallop
wallow
wallpaper
wall_in
wall_up
waltz
waltz_around
wamble
wan
wander
wane
wangle
wank
want
wanton
wanton_away
war
warble
ward
ward_off
ware
warehouse
warm
warm_the_bench
warm_to
warm_up
warn
warp
warrant
wash
wash_away
wash_down
wash_off
wash_one's_hands
wash_out
wash_up
wassail
waste
waste_one's_time
watch
watch_out
watch_over
water
water-wash
watercolor
watercolour
waterproof
water_down
water_ski
wattle
waul
wave
waver
wave_off
wawl
wax
waylay
weaken
wean
weaponize
wear
weary
wear_away
wear_down
wear_off
wear_on
wear_out
wear_round
wear_ship
wear_the_trousers
wear_thin
wear_upon
weather
weatherproof
weatherstrip
weave
web
wed
wedel
wedge
wee
wee-wee
weed
weed_out
weekend
weep
weigh
weight
weight-lift
weightlift
weight_down
weigh_anchor
weigh_down
weigh_on
weigh_the_anchor
welch
welcome
weld
well
well_out
well_over
well_up
welsh
welt
welter
wench
wend
westernise
westernize
wet
wet-nurse
whack
whale
wham
whang
whap
wharf
wheedle
wheel
wheelbarrow
wheel_around
wheeze
whelk
whelm
whelp
whet
whicker
whiff
while_away
whimper
whine
whinny
whip
whipsaw
whip_through
whip_up
whir
whirl
whirligig
whirlpool
whirl_around
whirr
whish
whisk
whisker
whisk_away
whisk_by
whisk_off
whisper
whistle
whistlestop
white
white-out
whiten
whiteout
whitewash
white_out
whittle
whittle_away
whittle_down
whiz
whizz
whizz_along
wholesale
whomp
whomp_up
whoop
whoop_it_up
whoosh
whop
whore
widen
widow
wield
wiggle
wigwag
will
wilt
win
wince
winch
wind
window-dress
window-shop
windsurf
wind_off
wind_up
wine
wine_and_dine
wing
wink
winkle
winkle_out
wink_at
winnow
winnow_out
winter
winterise
winterize
win_back
win_over
wipe
wipe_away
wipe_off
wipe_out
wipe_up
wire
wiretap
wisecrack
wise_up
wish
wish_well
witch
withdraw
wither
withhold
withstand
witness
wive
wobble
wolf
wolf-whistle
wolf_down
womanise
womanize
wonder
woo
woolgather
woosh
word
work
work_at
work_in
work_off
work_on
work_out
work_over
work_through
work_up
worm
worry
worsen
worship
worst
wound
wow
wrack
wrangle
wrap
wrap_up
wrawl
wreak
wreathe
wreck
wrench
wrest
wrestle
wrick
wriggle
wring
wring_from
wring_out
wrinkle
write
write_about
write_copy
write_down
write_in
write_in_code
write_of
write_off
write_on
write_out
write_up
writhe
wrong
x-ray
xerox
yacht
yack
yack_away
yak
yammer
yank
yap
yap_away
yarn
yarn-dye
yaup
yaw
yawl
yawn
yawp
yearn
yell
yellow
yelp
yen
yield
yield_up
yip
yodel
yoke
yowl
zap
zero
zero_in
zest
zigzag
zinc
zip
zipper
zip_by
zip_up
zone
zonk_out
zoom
zoom_along
zoom_in


# 2022.2.13
import requests,json, os, math,re
from elasticsearch import Elasticsearch,helpers
from collections import	Counter

#os.environ['eshost'] = 'es.corpusly.com'
#from so imoprt *
eshost	= os.getenv("eshost", "127.0.0.1") 
esport	= int(os.getenv("esport", 9200))
requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text

config = {  
		"settings" : {
			"refresh_interval": "1s",
			"number_of_shards": "3",
			"max_result_window":"2147483647",
			"index.mapping.ignore_malformed": "true",
			"analysis": {
			  "filter": {
				"postag_filter": {
				  "type": "pattern_capture",
				  "preserve_original": "false",
				  "patterns": [
					"(^([^_]+)_[a-z]+[,\\.$]?)",
					"(_[a-z\\-\\.\\'\\$0-9]+)$",
					"(_[a-z\\-\\.\\'\\$]+)",
					"(_[^\\w]+)_",
					"([^\\w])_"
				  ]
				},
				"postag_filter2": {
				  "type": "word_delimiter",
				  "type_table": [
					"^ => ALPHA",
					", => ALPHA",
					"$ => ALPHA",
					"_ => ALPHA",
					". => ALPHA",
					"- => ALPHA",
					"! => ALPHA",
					"? => ALPHA",
					"' => ALPHA",
					"0 => ALPHA",
					"1 => ALPHA",
					"2 => ALPHA",
					"3 => ALPHA",
					"4 => ALPHA",
					"5 => ALPHA",
					"6 => ALPHA",
					"7 => ALPHA",
					"8 => ALPHA",
					"9 => ALPHA"
				  ]
				},
				"unique_filter": {
				  "type": "unique",
				  "only_on_same_position": "true"
				}
			  },
			  "analyzer": {
				"postag_ana": {"filter": ["lowercase","postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" },
				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
				"err_ana": {"type": "custom",  "tokenizer": "path-tokenizer1"  },
				"chunk_ana": {"type": "custom", "tokenizer": "path-tokenizer2" },
				"kp_ana": { "filter": ["lowercase"], "type": "custom", "tokenizer": "keyword"}
			  },
			  "tokenizer": {
				"path-tokenizer": { "type": "path_hierarchy",  "delimiter": "/" },
				"path-tokenizer1": {"type": "path_hierarchy",  "delimiter": "|" },
				"path-tokenizer2": {"type": "path_hierarchy",  "delimiter": "/" },
				"feedback-tokenizer": { "type": "path_hierarchy",  "delimiter": "." }
				}
			},
			"number_of_replicas": "0"
		},
		"mappings" : {
			"_source": {"excludes": ["md5"]},
			"properties": {
			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"i": { "type": "integer"},
			"start": { "type": "integer"},
			"end": { "type": "integer"},
			"score": { "type": "float"},
			"offset": { "type": "float"},
			"final_score": { "type": "float"},
			"sid": { "type": "keyword"},
			"id": { "type": "keyword"},
			"rid": { "type": "integer"},
			"did": { "type": "integer"},
			"docid": { "type": "keyword"},
			"uid": { "type": "integer"},
			"eid": { "type": "integer"},
			"sntnum": { "type": "integer"},
			"wordnum": { "type": "integer"},
			"awl": { "type": "float"},
			"cnt": { "type": "long"},
			"vers": { "type": "integer"},
			"ver": { "type": "integer"},
			"ct": { "type": "integer"},
			"lem": { "type": "keyword"},
			"lex": { "type": "keyword"},
			"low": { "type": "keyword"},
			"pos": { "type": "keyword"},
			"tag": { "type": "keyword"},
			"term": { "type": "keyword"},

			"ap": { "type": "keyword"},
			"page": { "type": "keyword"},
			"pen": { "type": "keyword"},
			"label": { "type": "keyword"},
			"item": { "type": "keyword"},
			"lang": { "type": "keyword"},
			"key": { "type": "keyword"},
			"item_key": { "type": "keyword"},
			"score": { "type": "float"},
			"tmf": { "type": "float"},
			"stroke": { "type": "keyword", "index": "false"},
			"strokes": { "type": "keyword", "index": "false"},
			"en": { "type": "text", "analyzer": "standard","fielddata":"true"},
			"content": { "type": "text", "analyzer": "standard","fielddata":"true"},
			"zhseg": { "type": "text", "analyzer": "standard"},
			"zh": { "type": "text", "index": "false"},

			"src": { "type": "keyword"},
			"srcsnt": { "type": "keyword"},
			"segtype": { "type": "keyword"},
			"filename": { "type": "keyword"},
			"fullname": { "type": "keyword"},
			"sect": { "type": "keyword"},
			"index": { "type": "keyword"},
			"corpus": { "type": "keyword"},
			"folder": { "type": "keyword"},
			"head": { "type": "keyword"},
			"chunk": { "type": "keyword"},
			"type": { "type": "keyword"},
			"fn": { "type": "keyword"},
			"cat": { "type": "keyword"},
			"rel": { "type": "keyword"},
			"gov": { "type": "keyword"},
			"dep": { "type": "keyword"},
			"vp": { "type": "keyword"},
			"ap": { "type": "keyword"},
			"dp": { "type": "keyword"},
			"kp": { "type": "keyword"},
			"cate": { "type": "keyword"},
			"feedback": { "type": "keyword"},
			"tail":{ "type": "keyword"},
			"govpos":{ "type": "keyword"},
			"deppos":{ "type": "keyword"},
			"fd": { "type": "keyword"},
			"si": {
				   "type": "nested",
				   "properties": {
					  "s": {"type": "keyword"},
					  "i": {"type": "integer"}
				   }
				},
			"err": {"type": "text",  "analyzer": "err_ana"},
			"fd": { "type": "keyword"},
			"short_msg": { "type": "keyword"},
			"arr": { "type": "keyword", "index": "false" }, # dim arr of dsk
			"info": { "type": "keyword", "index": "false" ,"store": "false"},
			"kw": { "type": "keyword", "index": "false" ,"store": "false", "ignore_above": 60},
			"meta": { "type": "keyword", "index": "false" ,"store": "false"},
			"tc": {"type": "integer" , "index": "false"},
			"sc": {"type": "integer" , "index": "false"},
			"isum": {"type": "integer" , "index": "false"},
			"md5": { "type": "text", "store": "false", "norms":"false"},
			"toks": { "type": "keyword", "index": "false" ,"store": "false"},
			"snts": { "type": "keyword", "index": "false" },
			"blob": { "type": "binary", "store": "false"},
			"zlib": { "type": "binary", "store": "false"},
			"title": { "type": "text", "analyzer": "standard"},
			"essay": { "type": "text", "analyzer": "standard"},
			"body": { "type": "text", "index": "false" },
			"doc": { "type": "text", "index": "false" },#"doc": { "type": "keyword", "index": "false" ,"store": "false"}, # dim arr of dsk
			"tm": { "type": "date"}, #"format": "yyyy-MM-dd HH:mm:ss || yyyy-MM-dd || yyyy/MM/dd HH:mm:ss|| yyyy/MM/dd ||epoch_millis"
			"sdate": { "type": "date",  "format": "yyyy-MM-dd"},
			"csv": { "type": "keyword",  "index": "false"},
			"tsv": { "type": "keyword",  "index": "false"},
			"pair": { "type": "keyword",  "index": "false"},
			"json": { "type": "keyword",  "index": "false"},
			"v": { "type": "keyword",  "index": "false"},
			"n": { "type": "keyword",  "index": "false"},
			"adj": { "type": "keyword",  "index": "false"},
			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"}
		  }
		}
	}

#if eshost: 
es		= Elasticsearch([ f"http://{eshost}:{esport}" ])  
newindex= lambda idxname : (es.indices.delete(idxname) if es.indices.exists(idxname) else None, es.indices.create(idxname, config))[1] # body=
rows	= lambda query: requests.post(f"http://{eshost}:{esport}/_sql",json={"query": query}).json().get('rows',[]) 
sql		= lambda query: requests.post(f"http://{eshost}:{esport}/_sql",json={"query": query}).json().get('rows',[]) 
sntnum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] #75222
lexnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where low = '{w}' and type = 'tok'")[0][0] # opened = 70
lemnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where lem = '{w}' and type = 'tok'")[0][0] 
sqlsi	= lambda query: (si:=Counter(), [si.update({row[0]:1}) for row in sql(query)])[0]
warmup  = lambda host, port: requests.put(f"http://{host}:{port}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text

def readline(infile, sepa=None):
	with open(infile, 'r') as fp:
		while True:
			line = fp.readline()
			if not line: break
			yield line.strip().split(sepa) if sepa else line.strip()

def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.html
	try:
		if a is None or a <= 0 : a = 0.000001
		if b is None or b <= 0 : b = 0.000001
		E1 = c * (a + b) / (c + d)
		E2 = d * (a + b) / (c + d)
		G2 = round(2 * ((a * math.log(a / E1)) + (b * math.log(b / E2))), 2)
		if minus or  (minus is None and a/c < b/d): G2 = 0 - G2
		return G2
	except Exception as e:
		print ("likelihood ex:",e, a,b,c,d)
		return 0

#PUT twitter/_mapping {  "properties": {  "email": { "type": "keyword"  }  }}
#"stroke": { "type": "keyword", "index": "false"},
def delete_index(cp:str='testidx'): 
	return requests.delete(f"http://{eshost}:{esport}/{cp}").text #DELETE /twitter
def new_empty_index(cp:str='testidx', delete:bool=True): 
	if delete: requests.delete(f"http://{eshost}:{esport}/{cp}").text
	return requests.put(f"http://{eshost}:{esport}/{cp}", data={}).text #PUT twitter  {}
def add_mapping_keyword(kws:list, cp:str='testidx'): 
	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword"  }  }}).text for kw in kws]
def add_mapping_keyword_noindex(kws:list, cp:str='testidx'): 
	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword", "index": "false"} }}).text for kw in kws]
def add_mapping_float(kws:list, cp:str='testidx'): 
	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "float"  }  }}).text for kw in kws]
def add_mapping_integer(kws:list, cp:str='testidx'): 
	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "integer"  }  }}).text for kw in kws]
def add_mapping(dic:dict, cp:str='testidx'): 
	''' {"num":"integer", "awl":"float", "tag":"keyword"} '''
	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{k}": { "type": "{v}"  }  }}).text for k,v in dic.items()]

def ids(_ids:list, cp:str='inau'): 
	''' ["one","two"] '''
	sql	= { 
    "query": {
        "ids" : {
            "type" : "_doc",
            "values" : _ids
			}
		}
	}
	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()

def term_to_snts(sql): 
	rows = es.sql(sql) #f"select src from {cp} where type = 'trp' and gov='{gov}' and rel='{rel}' and dep='{dep}' limit {topk}"
	sql	= {
    "query": {
        "ids" : {
            "type" : "_doc",
            "values" : [row[0] for row in rows] #clec:snt-34993,  clec:snt-32678
			}
		}
	}
	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()

def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10): 
	''' '''
	sql	= {
  "query": {
    "match_phrase": {
      "snt": phrase
    }
  }
  , "size": topk
}
	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()

phrase_num = lambda phrase, cp='clec', topk=10: match_phrase(phrase, cp, topk)["hits"]["total"]["value"]

addpat	= lambda s : f"{s}_[^ ]*" if not s.startswith('_') else f"[^ ]*{s}_[^ ]*"   # if the last one, add $ 
rehyb   = lambda hyb: ' '.join([ addpat(s) for s in hyb.split()])  #'the_[^ ]* [^ ]*_NNS_[^ ]* of_[^ ]*'
heads   = lambda chunk:  ' '.join([s.split('_')[0].lower() for s in chunk.split()])		#the_the_DT_DET adventures_adventure_NNS_NOUN of_of_IN_ADP
def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10):
	''' the _NNS of -> {the books of: 13, the doors of: 7} , added 2021.10.13 '''
	sql= {
  "query": { 
    "bool": { 
      "must": [
        { "match_phrase": { "postag":  hyb}},
        { "match": { "type":"snt" }}
      ]
    }
  },
  "size":  size
}
	res = requests.post(f"http://{eshost}:{esport}/{index}/_search/", json=sql).json()
	si = Counter()
	repat = rehyb(hyb)
	for ar in res['hits']['hits']: 
		postag =  ar["_source"]['postag']
		m= re.search(repat,postag) #the_the_DT_DET adventures_adventure_NNS_NOUN of_of_IN_ADP
		if m : si.update({ heads(m.group()):1})
	return si.most_common(topk)

if __name__ == "__main__": 
	print(es)

'''
PUT twitter/_mapping 
{
  "properties": {
    "email": {
      "type": "keyword"
    }
  }
}
'''


#from uvirun import * 
#uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload
import json,os,uvicorn,time
from fastapi import FastAPI, File, UploadFile,Form, Body
from fastapi.responses import HTMLResponse

app	 = FastAPI() #app=FastAPI(title= "Essay Dsk Data API",description= "data for ***",version= "0.1.0",openapi_url="/fastapi/data_manger.json",docs_url="/fastapi/docs",redoc_url="/fastapi/redoc")
now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))

@app.get('/')
def home(): 
	return HTMLResponse(content=f"<h2>{getattr(app,'title') if hasattr(app,'title') else None}</h2><a href='/docs'> docs </a> | <a href='/redoc'> redoc </a><br>uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload <br><br>last update: {getattr(app,'tm')  if hasattr(app,'tm') else None} <br> started: {now()}")
# app.title = "hello" 
# app.tm = "2022.2.13"

if __name__ == '__main__':
	uvicorn.run(app, host='0.0.0.0', port=80)

'''
@app.get('/hello')
def hello(snt:str="I'm glad to meet you."): 
	return snt

from fastapi import FastAPI
from starlette.responses import JSONResponse 
from starlette.routing import Route

async def homepage(request):
    return JSONResponse({"index":"HOme"}) 

async def about(request):
    return JSONResponse({"index":"about"}) 

routes = [
    Route("/", endpoint=homepage,methods=["GET"]),
    Route("/about", endpoint=about,methods=["POST"]),
]

app=FastAPI(routes=routes)

'''